//line php5/php5.y:2
package php5

import __yyfmt__ "fmt"

//line php5/php5.y:2
import (
	"strconv"
	"strings"

	"github.com/z7zmey/php-parser/node"
	"github.com/z7zmey/php-parser/node/expr"
	"github.com/z7zmey/php-parser/node/expr/assign"
	"github.com/z7zmey/php-parser/node/expr/binary"
	"github.com/z7zmey/php-parser/node/expr/cast"
	"github.com/z7zmey/php-parser/node/name"
	"github.com/z7zmey/php-parser/node/scalar"
	"github.com/z7zmey/php-parser/node/stmt"
	"github.com/z7zmey/php-parser/token"
)

//line php5/php5.y:21
type yySymType struct {
	yys                     int
	node                    node.Node
	token                   token.Token
	boolWithToken           boolWithToken
	list                    []node.Node
	foreachVariable         foreachVariable
	nodesWithEndToken       *nodesWithEndToken
	simpleIndirectReference simpleIndirectReference
	altSyntaxNode           altSyntaxNode
}

const T_INCLUDE = 57346
const T_INCLUDE_ONCE = 57347
const T_EXIT = 57348
const T_IF = 57349
const T_LNUMBER = 57350
const T_DNUMBER = 57351
const T_STRING = 57352
const T_STRING_VARNAME = 57353
const T_VARIABLE = 57354
const T_NUM_STRING = 57355
const T_INLINE_HTML = 57356
const T_CHARACTER = 57357
const T_BAD_CHARACTER = 57358
const T_ENCAPSED_AND_WHITESPACE = 57359
const T_CONSTANT_ENCAPSED_STRING = 57360
const T_ECHO = 57361
const T_DO = 57362
const T_WHILE = 57363
const T_ENDWHILE = 57364
const T_FOR = 57365
const T_ENDFOR = 57366
const T_FOREACH = 57367
const T_ENDFOREACH = 57368
const T_DECLARE = 57369
const T_ENDDECLARE = 57370
const T_AS = 57371
const T_SWITCH = 57372
const T_ENDSWITCH = 57373
const T_CASE = 57374
const T_DEFAULT = 57375
const T_BREAK = 57376
const T_CONTINUE = 57377
const T_GOTO = 57378
const T_FUNCTION = 57379
const T_CONST = 57380
const T_RETURN = 57381
const T_TRY = 57382
const T_CATCH = 57383
const T_FINALLY = 57384
const T_THROW = 57385
const T_USE = 57386
const T_INSTEADOF = 57387
const T_GLOBAL = 57388
const T_VAR = 57389
const T_UNSET = 57390
const T_ISSET = 57391
const T_EMPTY = 57392
const T_HALT_COMPILER = 57393
const T_CLASS = 57394
const T_TRAIT = 57395
const T_INTERFACE = 57396
const T_EXTENDS = 57397
const T_IMPLEMENTS = 57398
const T_OBJECT_OPERATOR = 57399
const T_DOUBLE_ARROW = 57400
const T_LIST = 57401
const T_ARRAY = 57402
const T_CALLABLE = 57403
const T_CLASS_C = 57404
const T_TRAIT_C = 57405
const T_METHOD_C = 57406
const T_FUNC_C = 57407
const T_LINE = 57408
const T_FILE = 57409
const T_COMMENT = 57410
const T_DOC_COMMENT = 57411
const T_OPEN_TAG = 57412
const T_OPEN_TAG_WITH_ECHO = 57413
const T_CLOSE_TAG = 57414
const T_WHITESPACE = 57415
const T_START_HEREDOC = 57416
const T_END_HEREDOC = 57417
const T_DOLLAR_OPEN_CURLY_BRACES = 57418
const T_CURLY_OPEN = 57419
const T_PAAMAYIM_NEKUDOTAYIM = 57420
const T_NAMESPACE = 57421
const T_NS_C = 57422
const T_DIR = 57423
const T_NS_SEPARATOR = 57424
const T_ELLIPSIS = 57425
const T_EVAL = 57426
const T_REQUIRE = 57427
const T_REQUIRE_ONCE = 57428
const T_LOGICAL_OR = 57429
const T_LOGICAL_XOR = 57430
const T_LOGICAL_AND = 57431
const T_INSTANCEOF = 57432
const T_NEW = 57433
const T_CLONE = 57434
const T_ELSEIF = 57435
const T_ELSE = 57436
const T_ENDIF = 57437
const T_PRINT = 57438
const T_YIELD = 57439
const T_STATIC = 57440
const T_ABSTRACT = 57441
const T_FINAL = 57442
const T_PRIVATE = 57443
const T_PROTECTED = 57444
const T_PUBLIC = 57445
const T_INC = 57446
const T_DEC = 57447
const T_YIELD_FROM = 57448
const T_INT_CAST = 57449
const T_DOUBLE_CAST = 57450
const T_STRING_CAST = 57451
const T_ARRAY_CAST = 57452
const T_OBJECT_CAST = 57453
const T_BOOL_CAST = 57454
const T_UNSET_CAST = 57455
const T_COALESCE = 57456
const T_SPACESHIP = 57457
const T_NOELSE = 57458
const T_PLUS_EQUAL = 57459
const T_MINUS_EQUAL = 57460
const T_MUL_EQUAL = 57461
const T_DIV_EQUAL = 57462
const T_CONCAT_EQUAL = 57463
const T_MOD_EQUAL = 57464
const T_AND_EQUAL = 57465
const T_OR_EQUAL = 57466
const T_XOR_EQUAL = 57467
const T_SL_EQUAL = 57468
const T_SR_EQUAL = 57469
const T_POW_EQUAL = 57470
const T_BOOLEAN_OR = 57471
const T_BOOLEAN_AND = 57472
const T_IS_EQUAL = 57473
const T_IS_NOT_EQUAL = 57474
const T_IS_IDENTICAL = 57475
const T_IS_NOT_IDENTICAL = 57476
const T_IS_SMALLER_OR_EQUAL = 57477
const T_IS_GREATER_OR_EQUAL = 57478
const T_SL = 57479
const T_SR = 57480
const T_POW = 57481

var yyToknames = [...]string{
	"$end",
	"error",
	"$unk",
	"T_INCLUDE",
	"T_INCLUDE_ONCE",
	"T_EXIT",
	"T_IF",
	"T_LNUMBER",
	"T_DNUMBER",
	"T_STRING",
	"T_STRING_VARNAME",
	"T_VARIABLE",
	"T_NUM_STRING",
	"T_INLINE_HTML",
	"T_CHARACTER",
	"T_BAD_CHARACTER",
	"T_ENCAPSED_AND_WHITESPACE",
	"T_CONSTANT_ENCAPSED_STRING",
	"T_ECHO",
	"T_DO",
	"T_WHILE",
	"T_ENDWHILE",
	"T_FOR",
	"T_ENDFOR",
	"T_FOREACH",
	"T_ENDFOREACH",
	"T_DECLARE",
	"T_ENDDECLARE",
	"T_AS",
	"T_SWITCH",
	"T_ENDSWITCH",
	"T_CASE",
	"T_DEFAULT",
	"T_BREAK",
	"T_CONTINUE",
	"T_GOTO",
	"T_FUNCTION",
	"T_CONST",
	"T_RETURN",
	"T_TRY",
	"T_CATCH",
	"T_FINALLY",
	"T_THROW",
	"T_USE",
	"T_INSTEADOF",
	"T_GLOBAL",
	"T_VAR",
	"T_UNSET",
	"T_ISSET",
	"T_EMPTY",
	"T_HALT_COMPILER",
	"T_CLASS",
	"T_TRAIT",
	"T_INTERFACE",
	"T_EXTENDS",
	"T_IMPLEMENTS",
	"T_OBJECT_OPERATOR",
	"T_DOUBLE_ARROW",
	"T_LIST",
	"T_ARRAY",
	"T_CALLABLE",
	"T_CLASS_C",
	"T_TRAIT_C",
	"T_METHOD_C",
	"T_FUNC_C",
	"T_LINE",
	"T_FILE",
	"T_COMMENT",
	"T_DOC_COMMENT",
	"T_OPEN_TAG",
	"T_OPEN_TAG_WITH_ECHO",
	"T_CLOSE_TAG",
	"T_WHITESPACE",
	"T_START_HEREDOC",
	"T_END_HEREDOC",
	"T_DOLLAR_OPEN_CURLY_BRACES",
	"T_CURLY_OPEN",
	"T_PAAMAYIM_NEKUDOTAYIM",
	"T_NAMESPACE",
	"T_NS_C",
	"T_DIR",
	"T_NS_SEPARATOR",
	"T_ELLIPSIS",
	"T_EVAL",
	"T_REQUIRE",
	"T_REQUIRE_ONCE",
	"T_LOGICAL_OR",
	"T_LOGICAL_XOR",
	"T_LOGICAL_AND",
	"T_INSTANCEOF",
	"T_NEW",
	"T_CLONE",
	"T_ELSEIF",
	"T_ELSE",
	"T_ENDIF",
	"T_PRINT",
	"T_YIELD",
	"T_STATIC",
	"T_ABSTRACT",
	"T_FINAL",
	"T_PRIVATE",
	"T_PROTECTED",
	"T_PUBLIC",
	"T_INC",
	"T_DEC",
	"T_YIELD_FROM",
	"T_INT_CAST",
	"T_DOUBLE_CAST",
	"T_STRING_CAST",
	"T_ARRAY_CAST",
	"T_OBJECT_CAST",
	"T_BOOL_CAST",
	"T_UNSET_CAST",
	"T_COALESCE",
	"T_SPACESHIP",
	"T_NOELSE",
	"'\"'",
	"'`'",
	"'{'",
	"'}'",
	"';'",
	"':'",
	"'('",
	"')'",
	"'['",
	"']'",
	"'?'",
	"'&'",
	"'-'",
	"'+'",
	"'!'",
	"'~'",
	"'@'",
	"'$'",
	"','",
	"'='",
	"T_PLUS_EQUAL",
	"T_MINUS_EQUAL",
	"T_MUL_EQUAL",
	"T_DIV_EQUAL",
	"T_CONCAT_EQUAL",
	"T_MOD_EQUAL",
	"T_AND_EQUAL",
	"T_OR_EQUAL",
	"T_XOR_EQUAL",
	"T_SL_EQUAL",
	"T_SR_EQUAL",
	"T_POW_EQUAL",
	"T_BOOLEAN_OR",
	"T_BOOLEAN_AND",
	"'|'",
	"'^'",
	"T_IS_EQUAL",
	"T_IS_NOT_EQUAL",
	"T_IS_IDENTICAL",
	"T_IS_NOT_IDENTICAL",
	"'<'",
	"T_IS_SMALLER_OR_EQUAL",
	"'>'",
	"T_IS_GREATER_OR_EQUAL",
	"T_SL",
	"T_SR",
	"'.'",
	"'*'",
	"'/'",
	"'%'",
	"T_POW",
}
var yyStatenames = [...]string{}

const yyEofCode = 1
const yyErrCode = 2
const yyInitialStackSize = 16

//line php5/php5.y:3825

type foreachVariable struct {
	node  node.Node
	byRef bool
}

type nodesWithEndToken struct {
	nodes    []node.Node
	endToken token.Token
}

type boolWithToken struct {
	value bool
	token *token.Token
}

type simpleIndirectReference struct {
	all  []*expr.Variable
	last *expr.Variable
}

type altSyntaxNode struct {
	node  node.Node
	isAlt bool
}

//line yacctab:1
var yyExca = [...]int{
	-1, 1,
	1, -1,
	-2, 0,
	-1, 2,
	1, 1,
	-2, 0,
	-1, 51,
	104, 435,
	105, 435,
	-2, 433,
	-1, 102,
	78, 332,
	-2, 411,
	-1, 114,
	78, 451,
	123, 447,
	-2, 457,
	-1, 154,
	104, 435,
	105, 435,
	-2, 433,
	-1, 204,
	121, 306,
	124, 306,
	-2, 430,
	-1, 205,
	104, 435,
	105, 435,
	121, 307,
	124, 307,
	-2, 433,
	-1, 271,
	78, 451,
	-2, 457,
	-1, 298,
	78, 334,
	-2, 413,
	-1, 302,
	123, 448,
	-2, 458,
	-1, 311,
	78, 333,
	-2, 412,
	-1, 378,
	153, 0,
	154, 0,
	155, 0,
	156, 0,
	-2, 274,
	-1, 379,
	153, 0,
	154, 0,
	155, 0,
	156, 0,
	-2, 275,
	-1, 380,
	153, 0,
	154, 0,
	155, 0,
	156, 0,
	-2, 276,
	-1, 381,
	153, 0,
	154, 0,
	155, 0,
	156, 0,
	-2, 277,
	-1, 382,
	157, 0,
	158, 0,
	159, 0,
	160, 0,
	-2, 278,
	-1, 383,
	157, 0,
	158, 0,
	159, 0,
	160, 0,
	-2, 279,
	-1, 384,
	157, 0,
	158, 0,
	159, 0,
	160, 0,
	-2, 280,
	-1, 385,
	157, 0,
	158, 0,
	159, 0,
	160, 0,
	-2, 281,
	-1, 392,
	104, 435,
	105, 435,
	-2, 433,
	-1, 400,
	124, 142,
	-2, 147,
	-1, 462,
	104, 435,
	105, 435,
	124, 514,
	135, 514,
	-2, 433,
	-1, 463,
	124, 515,
	135, 515,
	-2, 430,
	-1, 464,
	104, 435,
	105, 435,
	-2, 433,
	-1, 486,
	124, 156,
	135, 156,
	-2, 430,
	-1, 487,
	104, 435,
	105, 435,
	124, 157,
	135, 157,
	-2, 433,
	-1, 493,
	123, 472,
	-2, 516,
	-1, 499,
	123, 472,
	-2, 517,
	-1, 521,
	78, 332,
	-2, 369,
	-1, 539,
	93, 135,
	94, 135,
	95, 135,
	-2, 0,
	-1, 551,
	124, 142,
	-2, 147,
	-1, 564,
	124, 142,
	-2, 147,
	-1, 581,
	121, 308,
	124, 308,
	-2, 430,
	-1, 582,
	104, 435,
	105, 435,
	121, 309,
	124, 309,
	-2, 433,
	-1, 681,
	78, 334,
	-2, 371,
	-1, 779,
	153, 0,
	154, 0,
	155, 0,
	156, 0,
	-2, 397,
	-1, 780,
	153, 0,
	154, 0,
	155, 0,
	156, 0,
	-2, 398,
	-1, 781,
	153, 0,
	154, 0,
	155, 0,
	156, 0,
	-2, 399,
	-1, 782,
	153, 0,
	154, 0,
	155, 0,
	156, 0,
	-2, 400,
	-1, 783,
	157, 0,
	158, 0,
	159, 0,
	160, 0,
	-2, 401,
	-1, 784,
	157, 0,
	158, 0,
	159, 0,
	160, 0,
	-2, 402,
	-1, 785,
	157, 0,
	158, 0,
	159, 0,
	160, 0,
	-2, 403,
	-1, 786,
	157, 0,
	158, 0,
	159, 0,
	160, 0,
	-2, 404,
	-1, 789,
	78, 333,
	-2, 370,
	-1, 839,
	37, 201,
	-2, 198,
	-1, 879,
	31, 128,
	32, 128,
	33, 128,
	120, 128,
	-2, 0,
	-1, 914,
	95, 140,
	-2, 0,
	-1, 916,
	31, 127,
	32, 127,
	33, 127,
	120, 127,
	-2, 0,
	-1, 943,
	93, 136,
	94, 136,
	95, 136,
	-2, 0,
	-1, 971,
	29, 189,
	-2, 4,
	-1, 980,
	124, 142,
	-2, 147,
	-1, 997,
	121, 193,
	-2, 195,
}

const yyPrivate = 57344

const yyLast = 8512

var yyAct = [...]int{

	102, 571, 843, 565, 1006, 965, 714, 807, 420, 826,
	123, 131, 606, 200, 340, 918, 734, 567, 452, 815,
	474, 683, 296, 594, 461, 592, 421, 61, 579, 142,
	319, 315, 39, 98, 264, 390, 158, 517, 130, 2,
	444, 115, 289, 192, 653, 118, 138, 140, 447, 544,
	145, 485, 179, 653, 978, 1002, 228, 228, 162, 477,
	941, 331, 940, 43, 7, 493, 959, 121, 330, 937,
	934, 6, 931, 26, 821, 932, 939, 450, 499, 121,
	121, 267, 44, 656, 658, 659, 657, 953, 432, 933,
	921, 897, 853, 737, 192, 657, 709, 562, 954, 632,
	251, 586, 618, 586, 298, 898, 735, 494, 153, 516,
	633, 653, 585, 619, 270, 655, 654, 137, 358, 325,
	179, 560, 272, 586, 793, 204, 311, 556, 510, 316,
	320, 728, 561, 323, 114, 258, 329, 241, 557, 5,
	506, 305, 511, 675, 677, 676, 678, 663, 664, 665,
	656, 658, 659, 657, 507, 543, 339, 141, 653, 359,
	121, 228, 655, 654, 310, 475, 355, 39, 178, 180,
	181, 179, 121, 360, 451, 159, 357, 350, 312, 162,
	356, 201, 1018, 976, 929, 907, 451, 451, 906, 120,
	192, 351, 313, 267, 133, 228, 665, 656, 658, 659,
	657, 120, 120, 904, 117, 861, 855, 653, 134, 791,
	661, 655, 654, 241, 745, 271, 653, 104, 595, 639,
	655, 654, 301, 228, 352, 631, 270, 386, 300, 177,
	176, 425, 630, 624, 272, 673, 674, 671, 672, 675,
	677, 676, 678, 663, 664, 665, 656, 658, 659, 657,
	302, 623, 663, 664, 665, 656, 658, 659, 657, 597,
	232, 232, 228, 175, 178, 180, 181, 179, 596, 595,
	456, 473, 749, 231, 231, 333, 440, 336, 393, 748,
	604, 294, 120, 611, 293, 273, 740, 453, 295, 610,
	287, 281, 254, 228, 303, 253, 399, 160, 265, 977,
	930, 1001, 950, 915, 885, 449, 882, 870, 825, 446,
	814, 727, 693, 634, 131, 396, 625, 621, 509, 430,
	428, 490, 513, 307, 241, 1013, 521, 271, 980, 297,
	892, 472, 139, 297, 504, 999, 824, 593, 818, 682,
	39, 449, 913, 434, 439, 492, 449, 587, 491, 502,
	498, 564, 505, 497, 809, 808, 876, 463, 465, 521,
	551, 126, 400, 121, 537, 232, 541, 288, 278, 275,
	467, 484, 7, 274, 344, 250, 471, 345, 231, 6,
	486, 222, 479, 480, 196, 195, 194, 144, 548, 495,
	122, 135, 436, 437, 989, 546, 552, 273, 448, 232,
	1010, 572, 1009, 572, 577, 572, 580, 458, 228, 400,
	265, 984, 231, 983, 126, 923, 121, 912, 437, 436,
	436, 126, 437, 121, 880, 588, 39, 232, 703, 704,
	229, 703, 704, 230, 448, 811, 805, 804, 798, 448,
	231, 295, 584, 712, 699, 547, 545, 5, 490, 233,
	542, 501, 539, 398, 348, 540, 615, 156, 981, 126,
	905, 121, 605, 423, 1019, 975, 232, 609, 449, 449,
	874, 917, 492, 498, 891, 491, 497, 890, 309, 231,
	308, 126, 888, 229, 732, 120, 230, 578, 581, 228,
	229, 306, 197, 230, 435, 830, 449, 232, 616, 449,
	614, 449, 233, 446, 295, 617, 224, 225, 316, 233,
	231, 987, 320, 257, 637, 638, 810, 521, 730, 702,
	641, 642, 802, 803, 681, 680, 521, 455, 229, 126,
	353, 230, 39, 521, 521, 521, 521, 521, 120, 645,
	695, 696, 648, 531, 259, 120, 650, 233, 635, 438,
	126, 647, 572, 125, 652, 710, 424, 700, 228, 228,
	228, 448, 448, 521, 7, 572, 718, 125, 726, 39,
	39, 6, 91, 126, 971, 731, 531, 572, 580, 569,
	570, 126, 729, 120, 612, 267, 687, 228, 228, 448,
	124, 459, 448, 713, 448, 705, 739, 707, 573, 295,
	723, 574, 454, 427, 295, 733, 282, 286, 260, 261,
	469, 504, 232, 738, 426, 304, 742, 741, 270, 736,
	126, 299, 321, 126, 816, 231, 272, 864, 228, 595,
	228, 518, 686, 515, 62, 512, 744, 449, 508, 5,
	457, 446, 573, 573, 754, 574, 574, 128, 129, 468,
	322, 54, 263, 317, 521, 521, 521, 521, 521, 521,
	521, 521, 521, 521, 521, 521, 521, 521, 521, 521,
	521, 521, 521, 521, 521, 521, 521, 521, 521, 521,
	521, 789, 743, 521, 576, 758, 295, 756, 295, 757,
	285, 295, 132, 232, 404, 132, 259, 720, 239, 750,
	402, 438, 463, 295, 790, 792, 231, 226, 234, 259,
	521, 208, 126, 207, 121, 985, 486, 228, 259, 271,
	827, 823, 259, 799, 795, 45, 1007, 438, 725, 572,
	448, 831, 986, 163, 531, 1017, 572, 850, 819, 338,
	812, 703, 704, 531, 559, 991, 828, 813, 957, 832,
	531, 531, 531, 531, 531, 851, 955, 856, 45, 453,
	260, 261, 232, 232, 232, 742, 796, 609, 706, 703,
	704, 858, 469, 260, 261, 231, 231, 231, 925, 896,
	531, 268, 260, 261, 269, 470, 260, 261, 521, 273,
	893, 232, 232, 259, 521, 521, 550, 1003, 284, 998,
	233, 960, 265, 935, 231, 231, 847, 848, 849, 846,
	845, 844, 901, 599, 878, 601, 600, 228, 126, 228,
	877, 760, 521, 883, 881, 572, 889, 884, 759, 854,
	875, 722, 232, 800, 232, 651, 120, 859, 860, 820,
	649, 646, 900, 572, 903, 231, 602, 231, 514, 481,
	39, 395, 324, 203, 202, 841, 285, 260, 261, 887,
	199, 842, 136, 1, 840, 944, 335, 228, 899, 829,
	521, 531, 531, 531, 531, 531, 531, 531, 531, 531,
	531, 531, 531, 531, 531, 531, 531, 531, 531, 531,
	531, 531, 531, 531, 531, 531, 531, 531, 519, 259,
	531, 922, 938, 259, 283, 908, 449, 1008, 256, 39,
	446, 343, 521, 936, 747, 847, 848, 849, 846, 845,
	844, 232, 753, 863, 445, 879, 909, 531, 608, 589,
	590, 519, 521, 591, 231, 521, 873, 894, 521, 684,
	572, 962, 572, 970, 39, 255, 39, 839, 994, 964,
	963, 902, 483, 192, 39, 403, 39, 39, 895, 838,
	521, 835, 575, 260, 261, 572, 970, 260, 261, 956,
	982, 566, 958, 39, 1005, 961, 1004, 39, 39, 521,
	724, 572, 394, 389, 993, 164, 572, 995, 341, 997,
	697, 538, 177, 176, 914, 928, 916, 979, 290, 448,
	460, 161, 39, 572, 1011, 531, 924, 157, 926, 927,
	1012, 531, 531, 318, 572, 1015, 992, 314, 127, 919,
	39, 232, 919, 232, 182, 183, 175, 178, 180, 181,
	179, 943, 528, 607, 231, 947, 231, 996, 948, 531,
	969, 968, 967, 192, 39, 966, 837, 836, 834, 401,
	39, 40, 945, 568, 15, 14, 822, 719, 801, 694,
	11, 841, 249, 75, 972, 76, 116, 842, 266, 64,
	840, 232, 89, 598, 90, 520, 101, 74, 12, 326,
	100, 99, 177, 176, 231, 79, 119, 531, 526, 519,
	3, 41, 0, 990, 0, 0, 0, 0, 519, 0,
	0, 0, 0, 0, 0, 519, 519, 519, 519, 519,
	188, 189, 190, 191, 182, 183, 175, 178, 180, 181,
	179, 847, 848, 849, 846, 845, 844, 0, 1014, 531,
	0, 0, 0, 0, 0, 519, 0, 1020, 169, 171,
	170, 192, 0, 833, 0, 0, 0, 0, 0, 531,
	558, 0, 531, 0, 0, 531, 0, 685, 0, 0,
	0, 0, 0, 0, 688, 689, 690, 691, 692, 0,
	620, 0, 809, 808, 0, 0, 0, 531, 193, 173,
	177, 176, 209, 210, 211, 212, 214, 215, 216, 217,
	218, 219, 220, 221, 213, 0, 531, 0, 0, 0,
	167, 168, 172, 174, 186, 187, 184, 185, 188, 189,
	190, 191, 182, 183, 175, 178, 180, 181, 179, 0,
	0, 0, 0, 0, 0, 0, 519, 519, 519, 519,
	519, 519, 519, 519, 519, 519, 519, 519, 519, 519,
	519, 519, 519, 519, 519, 519, 519, 519, 519, 519,
	519, 519, 519, 0, 0, 519, 0, 209, 210, 211,
	212, 214, 215, 216, 217, 218, 219, 220, 221, 213,
	0, 0, 0, 0, 0, 0, 0, 668, 666, 667,
	0, 0, 519, 0, 0, 761, 762, 763, 764, 765,
	766, 767, 768, 769, 770, 771, 772, 773, 774, 775,
	776, 777, 778, 779, 780, 781, 782, 783, 784, 785,
	786, 788, 869, 0, 685, 653, 0, 679, 661, 655,
	654, 209, 210, 211, 212, 214, 215, 216, 217, 218,
	219, 220, 221, 213, 0, 0, 0, 0, 0, 670,
	669, 660, 662, 673, 674, 671, 672, 675, 677, 676,
	678, 663, 664, 665, 656, 658, 659, 657, 0, 0,
	519, 0, 0, 0, 0, 0, 519, 519, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	349, 0, 0, 0, 0, 31, 0, 0, 0, 0,
	0, 0, 0, 0, 519, 209, 210, 211, 212, 214,
	215, 216, 217, 218, 219, 220, 221, 213, 0, 147,
	151, 155, 0, 0, 0, 165, 0, 0, 0, 868,
	0, 0, 51, 198, 0, 871, 872, 0, 206, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 223,
	0, 0, 519, 235, 236, 237, 238, 0, 154, 240,
	0, 242, 243, 244, 245, 246, 247, 248, 653, 252,
	0, 661, 655, 654, 262, 205, 0, 0, 0, 276,
	277, 0, 279, 280, 0, 0, 0, 0, 227, 227,
	0, 0, 0, 291, 519, 662, 673, 674, 671, 672,
	675, 677, 676, 678, 663, 664, 665, 656, 658, 659,
	657, 910, 0, 0, 519, 0, 0, 519, 0, 0,
	519, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 240, 0, 0, 0, 0,
	342, 0, 519, 0, 0, 0, 0, 0, 0, 126,
	0, 121, 0, 942, 0, 0, 0, 0, 0, 0,
	0, 519, 0, 361, 362, 363, 364, 365, 366, 367,
	368, 369, 370, 371, 372, 373, 374, 375, 376, 377,
	378, 379, 380, 381, 382, 383, 384, 385, 0, 387,
	0, 155, 0, 354, 0, 0, 0, 0, 717, 0,
	0, 0, 0, 0, 0, 406, 408, 409, 410, 411,
	412, 413, 414, 415, 416, 417, 418, 419, 229, 0,
	0, 230, 0, 0, 0, 0, 0, 391, 392, 0,
	0, 0, 0, 0, 0, 0, 0, 233, 0, 0,
	0, 0, 0, 0, 0, 0, 240, 0, 0, 433,
	433, 0, 0, 0, 0, 422, 441, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 716, 0, 0,
	155, 155, 0, 120, 466, 0, 0, 433, 0, 0,
	0, 0, 0, 433, 291, 0, 0, 0, 0, 433,
	433, 0, 0, 155, 443, 0, 433, 496, 0, 0,
	0, 0, 500, 0, 0, 0, 653, 462, 464, 661,
	655, 654, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 478, 0, 0, 0, 0,
	487, 669, 660, 662, 673, 674, 671, 672, 675, 677,
	676, 678, 663, 664, 665, 656, 658, 659, 657, 549,
	0, 0, 0, 0, 0, 0, 553, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 4, 0, 83, 84, 72, 18, 105, 106, 13,
	88, 121, 0, 30, 555, 0, 0, 95, 29, 20,
	19, 0, 21, 0, 33, 0, 34, 0, 0, 22,
	0, 155, 0, 23, 24, 38, 45, 16, 25, 36,
	0, 0, 37, 10, 0, 27, 0, 32, 81, 82,
	8, 46, 48, 50, 0, 0, 0, 0, 52, 96,
	0, 94, 110, 111, 112, 107, 108, 0, 582, 0,
	583, 0, 0, 93, 0, 0, 0, 613, 9, 113,
	109, 103, 0, 85, 86, 87, 0, 0, 0, 0,
	80, 53, 0, 0, 0, 78, 42, 28, 47, 49,
	0, 626, 628, 55, 56, 911, 65, 66, 67, 68,
	69, 70, 71, 0, 0, 636, 92, 77, 17, 644,
	35, 0, 63, 0, 97, 0, 0, 0, 58, 57,
	59, 60, 73, 120, 668, 666, 667, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 478, 0, 653, 0, 0, 0, 655, 654, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 342, 701,
	0, 0, 653, 0, 679, 661, 655, 654, 0, 0,
	711, 673, 674, 671, 672, 675, 677, 676, 678, 663,
	664, 665, 656, 658, 659, 657, 670, 669, 660, 662,
	673, 674, 671, 672, 675, 677, 676, 678, 663, 664,
	665, 656, 658, 659, 657, 0, 0, 0, 0, 433,
	391, 715, 715, 0, 0, 0, 0, 0, 0, 0,
	746, 0, 0, 0, 0, 0, 433, 751, 668, 666,
	667, 0, 0, 0, 0, 155, 0, 0, 0, 422,
	422, 0, 0, 0, 0, 0, 0, 0, 0, 155,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 653, 867, 679, 661,
	655, 654, 462, 666, 667, 0, 0, 0, 0, 0,
	478, 0, 478, 0, 0, 0, 487, 0, 0, 0,
	670, 669, 660, 662, 673, 674, 671, 672, 675, 677,
	676, 678, 663, 664, 665, 656, 658, 659, 657, 0,
	653, 0, 679, 661, 655, 654, 0, 0, 0, 806,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 670, 669, 660, 662, 673, 674,
	671, 672, 675, 677, 676, 678, 663, 664, 665, 656,
	658, 659, 657, 852, 0, 0, 433, 0, 0, 0,
	0, 0, 0, 0, 433, 433, 0, 0, 0, 817,
	0, 865, 0, 0, 0, 0, 0, 0, 4, 0,
	83, 84, 72, 18, 105, 106, 13, 88, 121, 0,
	30, 0, 0, 0, 95, 29, 20, 19, 0, 21,
	0, 33, 0, 34, 0, 0, 22, 0, 0, 0,
	23, 24, 38, 45, 16, 25, 36, 0, 0, 37,
	10, 342, 27, 0, 32, 81, 82, 8, 46, 48,
	50, 0, 0, 0, 0, 52, 96, 0, 94, 110,
	111, 112, 107, 108, 0, 0, 0, 0, 0, 0,
	93, 0, 0, 0, 0, 9, 113, 109, 103, 0,
	85, 86, 87, 0, 0, 0, 0, 80, 53, 715,
	0, 422, 78, 42, 28, 47, 49, 0, 0, 0,
	55, 56, 0, 65, 66, 67, 68, 69, 70, 71,
	0, 0, 0, 92, 77, 17, 503, 35, 0, 63,
	0, 97, 0, 0, 0, 58, 57, 59, 60, 73,
	120, 0, 0, 0, 0, 0, 0, 0, 4, 478,
	83, 84, 72, 18, 105, 106, 13, 88, 121, 0,
	30, 0, 0, 0, 95, 29, 20, 19, 0, 21,
	0, 33, 0, 34, 0, 0, 22, 0, 0, 0,
	23, 24, 38, 45, 16, 25, 36, 0, 0, 37,
	10, 0, 27, 0, 32, 81, 82, 8, 46, 48,
	50, 0, 0, 0, 0, 52, 96, 0, 94, 110,
	111, 112, 107, 108, 0, 0, 0, 0, 0, 0,
	93, 0, 0, 0, 0, 9, 113, 109, 103, 0,
	85, 86, 87, 0, 0, 0, 0, 80, 53, 0,
	0, 0, 78, 42, 28, 47, 49, 0, 0, 0,
	55, 56, 0, 65, 66, 67, 68, 69, 70, 71,
	0, 0, 0, 92, 77, 17, 0, 35, 0, 63,
	0, 97, 0, 0, 0, 58, 57, 59, 60, 73,
	120, 328, 0, 83, 84, 72, 18, 105, 106, 13,
	88, 121, 0, 30, 0, 0, 0, 95, 29, 20,
	19, 0, 21, 0, 33, 0, 34, 0, 0, 22,
	0, 0, 0, 23, 24, 38, 45, 0, 25, 36,
	0, 0, 37, 0, 0, 27, 0, 32, 81, 82,
	332, 46, 48, 50, 0, 0, 0, 0, 52, 96,
	0, 94, 110, 111, 112, 107, 108, 0, 0, 0,
	0, 0, 0, 93, 0, 0, 0, 0, 143, 113,
	109, 103, 0, 85, 86, 87, 0, 0, 0, 0,
	80, 53, 0, 0, 0, 78, 42, 28, 47, 49,
	0, 0, 0, 55, 56, 0, 65, 66, 67, 68,
	69, 70, 71, 0, 0, 0, 92, 77, 17, 1021,
	35, 0, 63, 0, 97, 0, 0, 0, 58, 57,
	59, 60, 73, 120, 328, 0, 83, 84, 72, 18,
	105, 106, 13, 88, 121, 0, 30, 0, 0, 0,
	95, 29, 20, 19, 0, 21, 0, 33, 0, 34,
	0, 0, 22, 0, 0, 0, 23, 24, 38, 45,
	0, 25, 36, 0, 0, 37, 0, 0, 27, 0,
	32, 81, 82, 332, 46, 48, 50, 0, 0, 0,
	0, 52, 96, 0, 94, 110, 111, 112, 107, 108,
	0, 0, 0, 0, 0, 0, 93, 0, 0, 0,
	0, 143, 113, 109, 103, 0, 85, 86, 87, 0,
	0, 0, 0, 80, 53, 0, 0, 0, 78, 42,
	28, 47, 49, 0, 0, 0, 55, 56, 0, 65,
	66, 67, 68, 69, 70, 71, 0, 0, 0, 92,
	77, 17, 1016, 35, 0, 63, 0, 97, 0, 0,
	0, 58, 57, 59, 60, 73, 120, 328, 0, 83,
	84, 72, 18, 105, 106, 13, 88, 121, 0, 30,
	0, 0, 0, 95, 29, 20, 19, 0, 21, 0,
	33, 0, 34, 0, 0, 22, 0, 0, 0, 23,
	24, 38, 45, 0, 25, 36, 0, 0, 37, 0,
	0, 27, 0, 32, 81, 82, 332, 46, 48, 50,
	0, 0, 0, 0, 52, 96, 0, 94, 110, 111,
	112, 107, 108, 0, 0, 0, 0, 0, 0, 93,
	0, 0, 0, 0, 143, 113, 109, 103, 0, 85,
	86, 87, 0, 0, 0, 0, 80, 53, 0, 0,
	0, 78, 42, 28, 47, 49, 0, 0, 0, 55,
	56, 0, 65, 66, 67, 68, 69, 70, 71, 0,
	0, 0, 92, 77, 17, 1000, 35, 0, 63, 0,
	97, 0, 0, 0, 58, 57, 59, 60, 73, 120,
	328, 0, 83, 84, 72, 18, 105, 106, 13, 88,
	121, 0, 30, 0, 0, 0, 95, 29, 20, 19,
	0, 21, 988, 33, 0, 34, 0, 0, 22, 0,
	0, 0, 23, 24, 38, 45, 0, 25, 36, 0,
	0, 37, 0, 0, 27, 0, 32, 81, 82, 332,
	46, 48, 50, 0, 0, 0, 0, 52, 96, 0,
	94, 110, 111, 112, 107, 108, 0, 0, 0, 0,
	0, 0, 93, 0, 0, 0, 0, 143, 113, 109,
	103, 0, 85, 86, 87, 0, 0, 0, 0, 80,
	53, 0, 0, 0, 78, 42, 28, 47, 49, 0,
	0, 0, 55, 56, 0, 65, 66, 67, 68, 69,
	70, 71, 0, 0, 0, 92, 77, 17, 0, 35,
	0, 63, 0, 97, 0, 0, 0, 58, 57, 59,
	60, 73, 120, 328, 0, 83, 84, 72, 18, 105,
	106, 13, 88, 121, 0, 30, 0, 0, 0, 95,
	29, 20, 19, 0, 21, 0, 33, 974, 34, 0,
	0, 22, 0, 0, 0, 23, 24, 38, 45, 0,
	25, 36, 0, 0, 37, 0, 0, 27, 0, 32,
	81, 82, 332, 46, 48, 50, 0, 0, 0, 0,
	52, 96, 0, 94, 110, 111, 112, 107, 108, 0,
	0, 0, 0, 0, 0, 93, 0, 0, 0, 0,
	143, 113, 109, 103, 0, 85, 86, 87, 0, 0,
	0, 0, 80, 53, 0, 0, 0, 78, 42, 28,
	47, 49, 0, 0, 0, 55, 56, 0, 65, 66,
	67, 68, 69, 70, 71, 0, 0, 0, 92, 77,
	17, 0, 35, 0, 63, 0, 97, 0, 0, 0,
	58, 57, 59, 60, 73, 120, 328, 0, 83, 84,
	72, 18, 105, 106, 13, 88, 121, 0, 30, 0,
	0, 0, 95, 29, 20, 19, 0, 21, 0, 33,
	0, 34, 0, 0, 22, 0, 0, 0, 23, 24,
	38, 45, 0, 25, 36, 0, 0, 37, 0, 0,
	27, 0, 32, 81, 82, 332, 46, 48, 50, 0,
	0, 0, 0, 52, 96, 0, 94, 110, 111, 112,
	107, 108, 0, 0, 0, 0, 0, 0, 93, 0,
	0, 0, 0, 143, 113, 109, 103, 0, 85, 86,
	87, 0, 0, 0, 0, 80, 53, 0, 0, 0,
	78, 42, 28, 47, 49, 0, 0, 0, 55, 56,
	0, 65, 66, 67, 68, 69, 70, 71, 0, 0,
	0, 92, 77, 17, 973, 35, 0, 63, 0, 97,
	0, 0, 0, 58, 57, 59, 60, 73, 120, 328,
	0, 83, 84, 72, 18, 105, 106, 13, 88, 121,
	0, 30, 0, 0, 0, 95, 29, 20, 19, 0,
	21, 0, 33, 0, 34, 0, 0, 22, 0, 0,
	0, 23, 24, 38, 45, 0, 25, 36, 0, 0,
	37, 0, 0, 27, 0, 32, 81, 82, 332, 46,
	48, 50, 0, 0, 0, 0, 52, 96, 0, 94,
	110, 111, 112, 107, 108, 0, 0, 0, 0, 0,
	0, 93, 0, 0, 0, 0, 143, 113, 109, 103,
	0, 85, 86, 87, 0, 0, 0, 0, 80, 53,
	0, 0, 0, 78, 42, 28, 47, 49, 0, 0,
	0, 55, 56, 0, 65, 66, 67, 68, 69, 70,
	71, 0, 0, 0, 92, 77, 17, 952, 35, 0,
	63, 0, 97, 0, 0, 0, 58, 57, 59, 60,
	73, 120, 328, 0, 83, 84, 72, 18, 105, 106,
	13, 88, 121, 0, 30, 0, 0, 0, 95, 29,
	20, 19, 0, 21, 0, 33, 0, 34, 0, 0,
	22, 0, 0, 0, 23, 24, 38, 45, 0, 25,
	36, 0, 0, 37, 0, 0, 27, 0, 32, 81,
	82, 332, 46, 48, 50, 0, 0, 0, 0, 52,
	96, 0, 94, 110, 111, 112, 107, 108, 0, 0,
	0, 0, 0, 0, 93, 0, 0, 0, 0, 143,
	113, 109, 103, 0, 85, 86, 87, 0, 0, 0,
	0, 80, 53, 0, 0, 0, 78, 42, 28, 47,
	49, 0, 0, 0, 55, 56, 0, 65, 66, 67,
	68, 69, 70, 71, 0, 0, 0, 92, 77, 17,
	951, 35, 0, 63, 0, 97, 0, 0, 0, 58,
	57, 59, 60, 73, 120, 328, 0, 83, 84, 72,
	18, 105, 106, 13, 88, 121, 0, 30, 0, 0,
	0, 95, 29, 20, 19, 0, 21, 0, 33, 0,
	34, 0, 0, 22, 0, 0, 0, 23, 24, 38,
	45, 0, 25, 36, 0, 0, 37, 0, 0, 27,
	0, 32, 81, 82, 332, 46, 48, 50, 0, 0,
	0, 0, 52, 96, 0, 94, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 143, 113, 109, 103, 0, 85, 86, 87,
	0, 0, 0, 0, 80, 53, 0, 0, 0, 78,
	42, 28, 47, 49, 0, 0, 0, 55, 56, 0,
	65, 66, 67, 68, 69, 70, 71, 0, 0, 0,
	92, 77, 17, 949, 35, 0, 63, 0, 97, 0,
	0, 0, 58, 57, 59, 60, 73, 120, 328, 0,
	83, 84, 72, 18, 105, 106, 13, 88, 121, 0,
	30, 0, 0, 0, 95, 29, 20, 19, 0, 21,
	0, 33, 0, 34, 886, 0, 22, 0, 0, 0,
	23, 24, 38, 45, 0, 25, 36, 0, 0, 37,
	0, 0, 27, 0, 32, 81, 82, 332, 46, 48,
	50, 0, 0, 0, 0, 52, 96, 0, 94, 110,
	111, 112, 107, 108, 0, 0, 0, 0, 0, 0,
	93, 0, 0, 0, 0, 143, 113, 109, 103, 0,
	85, 86, 87, 0, 0, 0, 0, 80, 53, 0,
	0, 0, 78, 42, 28, 47, 49, 0, 0, 0,
	55, 56, 0, 65, 66, 67, 68, 69, 70, 71,
	0, 0, 0, 92, 77, 17, 0, 35, 0, 63,
	0, 97, 0, 0, 0, 58, 57, 59, 60, 73,
	120, 328, 0, 83, 84, 72, 18, 105, 106, 13,
	88, 121, 0, 30, 0, 0, 0, 95, 29, 20,
	19, 698, 21, 0, 33, 0, 34, 0, 0, 22,
	0, 0, 0, 23, 24, 38, 45, 0, 25, 36,
	0, 0, 37, 0, 0, 27, 0, 32, 81, 82,
	332, 46, 48, 50, 0, 0, 0, 0, 52, 96,
	0, 94, 110, 111, 112, 107, 108, 0, 0, 0,
	0, 0, 0, 93, 0, 0, 0, 0, 143, 113,
	109, 103, 0, 85, 86, 87, 0, 0, 0, 0,
	80, 53, 0, 0, 0, 78, 42, 28, 47, 49,
	0, 0, 0, 55, 56, 0, 65, 66, 67, 68,
	69, 70, 71, 0, 0, 0, 92, 77, 17, 0,
	35, 0, 63, 0, 97, 0, 0, 0, 58, 57,
	59, 60, 73, 120, 328, 0, 83, 84, 72, 18,
	105, 106, 13, 88, 121, 0, 30, 0, 0, 0,
	95, 29, 20, 19, 0, 21, 0, 33, 0, 34,
	0, 0, 22, 0, 0, 0, 23, 24, 38, 45,
	0, 25, 36, 0, 0, 37, 0, 0, 27, 0,
	32, 81, 82, 332, 46, 48, 50, 0, 0, 0,
	0, 52, 96, 0, 94, 110, 111, 112, 107, 108,
	0, 0, 0, 0, 0, 0, 93, 0, 0, 0,
	0, 143, 113, 109, 103, 0, 85, 86, 87, 0,
	0, 0, 0, 80, 53, 0, 0, 0, 78, 42,
	28, 47, 49, 0, 0, 0, 55, 56, 0, 65,
	66, 67, 68, 69, 70, 71, 0, 0, 0, 92,
	77, 17, 563, 35, 0, 63, 0, 97, 0, 0,
	0, 58, 57, 59, 60, 73, 120, 328, 0, 83,
	84, 72, 18, 105, 106, 13, 88, 121, 0, 30,
	0, 0, 0, 95, 29, 20, 19, 0, 21, 0,
	33, 0, 34, 0, 0, 22, 0, 0, 0, 23,
	24, 38, 45, 0, 25, 36, 0, 0, 37, 0,
	0, 27, 0, 32, 81, 82, 332, 46, 48, 50,
	0, 0, 0, 0, 52, 96, 0, 94, 110, 111,
	112, 107, 108, 0, 0, 0, 0, 0, 0, 93,
	0, 0, 0, 0, 143, 113, 109, 103, 0, 85,
	86, 87, 0, 0, 0, 0, 80, 53, 0, 0,
	0, 78, 42, 28, 47, 49, 0, 0, 0, 55,
	56, 0, 65, 66, 67, 68, 69, 70, 71, 0,
	0, 0, 92, 77, 17, 327, 35, 0, 63, 0,
	97, 0, 0, 0, 58, 57, 59, 60, 73, 120,
	328, 0, 83, 84, 72, 18, 105, 106, 13, 88,
	121, 0, 30, 0, 0, 0, 95, 29, 20, 19,
	0, 21, 0, 33, 0, 34, 0, 0, 22, 0,
	0, 0, 23, 24, 38, 45, 0, 25, 36, 0,
	0, 37, 0, 0, 27, 0, 32, 81, 82, 332,
	46, 48, 50, 0, 0, 0, 0, 52, 96, 0,
	94, 110, 111, 112, 107, 108, 0, 0, 0, 0,
	0, 0, 93, 0, 0, 0, 0, 143, 113, 109,
	103, 0, 85, 86, 87, 0, 0, 0, 0, 80,
	53, 0, 0, 0, 78, 42, 28, 47, 49, 0,
	0, 0, 55, 56, 0, 65, 66, 67, 68, 69,
	70, 71, 0, 0, 0, 92, 77, 17, 0, 35,
	0, 63, 0, 97, 0, 0, 0, 58, 57, 59,
	60, 73, 120, 83, 84, 72, 18, 105, 106, 13,
	88, 121, 0, 30, 0, 0, 0, 95, 29, 20,
	19, 0, 21, 0, 33, 0, 34, 0, 0, 22,
	0, 0, 0, 23, 24, 38, 45, 0, 25, 36,
	0, 0, 37, 0, 0, 27, 0, 32, 81, 82,
	0, 0, 0, 0, 0, 0, 0, 0, 52, 96,
	0, 94, 110, 111, 112, 107, 108, 0, 0, 0,
	0, 0, 0, 93, 0, 0, 0, 0, 143, 113,
	109, 103, 0, 85, 86, 87, 0, 0, 0, 0,
	80, 53, 0, 0, 0, 78, 42, 28, 0, 0,
	0, 0, 0, 55, 56, 0, 65, 66, 67, 68,
	69, 70, 71, 0, 0, 0, 92, 77, 17, 0,
	35, 946, 63, 0, 97, 0, 0, 0, 58, 57,
	59, 60, 73, 120, 83, 84, 72, 18, 105, 106,
	13, 88, 121, 0, 30, 0, 0, 0, 95, 29,
	20, 19, 0, 21, 0, 33, 0, 34, 0, 0,
	22, 0, 0, 0, 23, 24, 38, 45, 0, 25,
	36, 0, 0, 37, 0, 0, 27, 0, 32, 81,
	82, 0, 0, 0, 0, 0, 0, 0, 0, 52,
	96, 0, 94, 110, 111, 112, 107, 108, 0, 0,
	0, 0, 0, 0, 93, 0, 0, 0, 0, 143,
	113, 109, 103, 0, 85, 86, 87, 0, 0, 0,
	0, 80, 53, 0, 0, 0, 78, 42, 28, 0,
	0, 0, 0, 0, 55, 56, 0, 65, 66, 67,
	68, 69, 70, 71, 0, 0, 0, 92, 77, 17,
	0, 35, 920, 63, 0, 97, 0, 0, 0, 58,
	57, 59, 60, 73, 120, 83, 84, 72, 18, 105,
	106, 13, 88, 121, 0, 30, 0, 0, 0, 95,
	29, 20, 19, 0, 21, 0, 33, 0, 34, 0,
	0, 22, 0, 0, 0, 23, 24, 38, 45, 0,
	25, 36, 0, 0, 37, 0, 0, 27, 0, 32,
	81, 82, 0, 0, 0, 0, 0, 0, 0, 0,
	52, 96, 0, 94, 110, 111, 112, 107, 108, 0,
	0, 0, 0, 0, 0, 93, 0, 0, 0, 0,
	143, 113, 109, 103, 0, 85, 86, 87, 0, 0,
	0, 0, 80, 53, 0, 0, 0, 78, 42, 28,
	0, 0, 0, 0, 0, 55, 56, 0, 65, 66,
	67, 68, 69, 70, 71, 0, 0, 0, 92, 77,
	17, 0, 35, 721, 63, 0, 97, 0, 0, 0,
	58, 57, 59, 60, 73, 120, 83, 84, 72, 18,
	105, 106, 13, 88, 121, 0, 30, 0, 0, 0,
	95, 29, 20, 19, 0, 21, 0, 33, 0, 34,
	0, 0, 22, 0, 0, 0, 23, 24, 38, 45,
	0, 25, 36, 0, 0, 37, 0, 0, 27, 0,
	32, 81, 82, 0, 0, 0, 0, 0, 0, 0,
	0, 52, 96, 0, 94, 110, 111, 112, 107, 108,
	0, 0, 0, 0, 0, 0, 93, 0, 0, 0,
	0, 143, 113, 109, 103, 0, 85, 86, 87, 0,
	0, 0, 0, 80, 53, 0, 0, 0, 78, 42,
	28, 0, 0, 0, 0, 0, 55, 56, 0, 65,
	66, 67, 68, 69, 70, 71, 0, 0, 0, 92,
	77, 17, 0, 35, 337, 63, 0, 97, 0, 0,
	0, 58, 57, 59, 60, 73, 120, 83, 84, 72,
	18, 105, 106, 13, 88, 121, 0, 30, 0, 0,
	0, 95, 29, 20, 19, 0, 21, 0, 33, 0,
	34, 0, 0, 22, 0, 0, 0, 23, 24, 38,
	45, 0, 25, 36, 0, 0, 37, 0, 0, 27,
	0, 32, 81, 82, 0, 0, 0, 0, 0, 0,
	0, 0, 52, 96, 0, 94, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 143, 113, 109, 103, 0, 85, 86, 87,
	0, 0, 0, 0, 80, 53, 0, 0, 0, 78,
	42, 28, 0, 0, 0, 0, 0, 55, 56, 0,
	65, 66, 67, 68, 69, 70, 71, 0, 0, 0,
	92, 77, 17, 0, 35, 334, 63, 0, 97, 0,
	0, 0, 58, 57, 59, 60, 73, 120, 83, 84,
	72, 18, 105, 106, 13, 88, 121, 0, 30, 0,
	0, 0, 95, 29, 20, 19, 0, 21, 0, 33,
	0, 34, 0, 0, 22, 0, 0, 0, 23, 24,
	38, 45, 0, 25, 36, 0, 0, 37, 0, 0,
	27, 0, 32, 81, 82, 0, 0, 0, 0, 0,
	0, 0, 0, 52, 96, 0, 94, 110, 111, 112,
	107, 108, 0, 0, 0, 0, 0, 0, 93, 0,
	0, 0, 0, 143, 113, 109, 103, 0, 85, 86,
	87, 0, 192, 0, 0, 80, 53, 0, 0, 0,
	78, 42, 28, 0, 0, 0, 0, 0, 55, 56,
	0, 65, 66, 67, 68, 69, 70, 71, 0, 0,
	0, 92, 77, 17, 0, 35, 0, 63, 0, 97,
	173, 177, 176, 58, 57, 59, 60, 73, 120, 169,
	171, 170, 192, 0, 0, 0, 0, 0, 0, 0,
	0, 167, 168, 172, 174, 186, 187, 184, 185, 188,
	189, 190, 191, 182, 183, 175, 178, 180, 181, 179,
	0, 0, 862, 0, 0, 0, 0, 0, 0, 193,
	173, 177, 176, 169, 171, 170, 192, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 167, 168, 172, 174, 186, 187, 184, 185, 188,
	189, 190, 191, 182, 183, 175, 178, 180, 181, 179,
	0, 0, 857, 193, 173, 177, 176, 668, 666, 667,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 794, 0, 0, 167, 168, 172, 174, 186,
	187, 184, 185, 188, 189, 190, 191, 182, 183, 175,
	178, 180, 181, 179, 797, 653, 0, 679, 661, 655,
	654, 668, 666, 667, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 755, 0, 0, 670,
	669, 660, 662, 673, 674, 671, 672, 675, 677, 676,
	678, 663, 664, 665, 656, 658, 659, 657, 0, 653,
	0, 679, 661, 655, 654, 169, 171, 170, 192, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 670, 669, 660, 662, 673, 674, 671,
	672, 675, 677, 676, 678, 663, 664, 665, 656, 658,
	659, 657, 0, 0, 0, 193, 173, 177, 176, 0,
	0, 0, 0, 169, 171, 170, 192, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 167, 168, 172,
	174, 186, 187, 184, 185, 188, 189, 190, 191, 182,
	183, 175, 178, 180, 181, 179, 752, 0, 0, 0,
	0, 0, 0, 193, 173, 177, 176, 0, 0, 0,
	0, 169, 171, 170, 192, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 167, 168, 172, 174, 186,
	187, 184, 185, 188, 189, 190, 191, 182, 183, 175,
	178, 180, 181, 179, 708, 0, 0, 0, 0, 0,
	0, 193, 173, 177, 176, 0, 0, 0, 0, 169,
	171, 170, 192, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 167, 168, 172, 174, 186, 187, 184,
	185, 188, 189, 190, 191, 182, 183, 175, 178, 180,
	181, 179, 643, 0, 0, 0, 0, 0, 0, 193,
	173, 177, 176, 0, 0, 0, 0, 169, 171, 170,
	192, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 167, 168, 172, 174, 186, 187, 184, 185, 188,
	189, 190, 191, 182, 183, 175, 178, 180, 181, 179,
	640, 0, 0, 0, 0, 0, 0, 193, 173, 177,
	176, 169, 171, 170, 192, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 167,
	168, 172, 174, 186, 187, 184, 185, 188, 189, 190,
	191, 182, 183, 175, 178, 180, 181, 179, 622, 0,
	0, 193, 173, 177, 176, 0, 0, 0, 0, 169,
	171, 170, 192, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 167, 168, 172, 174, 186, 187, 184,
	185, 188, 189, 190, 191, 182, 183, 175, 178, 180,
	181, 179, 603, 0, 0, 0, 0, 0, 0, 193,
	173, 177, 176, 0, 0, 169, 171, 170, 192, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	476, 167, 168, 172, 174, 186, 187, 184, 185, 188,
	189, 190, 191, 182, 183, 175, 178, 180, 181, 179,
	554, 0, 0, 0, 0, 193, 173, 177, 176, 169,
	171, 170, 192, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 167, 168, 172,
	174, 186, 187, 184, 185, 188, 189, 190, 191, 182,
	183, 175, 178, 180, 181, 179, 0, 0, 0, 193,
	173, 177, 176, 169, 171, 170, 192, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 405, 0,
	0, 167, 168, 172, 174, 186, 187, 184, 185, 188,
	189, 190, 191, 182, 183, 175, 178, 180, 181, 179,
	429, 0, 0, 193, 173, 177, 176, 169, 171, 170,
	192, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 167, 168, 172, 174, 186,
	187, 184, 185, 188, 189, 190, 191, 182, 183, 175,
	178, 180, 181, 179, 0, 0, 0, 193, 173, 177,
	176, 0, 0, 0, 169, 171, 170, 192, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 167,
	168, 172, 174, 186, 187, 184, 185, 188, 189, 190,
	191, 182, 183, 175, 178, 180, 181, 179, 397, 0,
	0, 0, 0, 0, 193, 173, 177, 176, 0, 0,
	0, 169, 171, 170, 192, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 167, 168, 172, 174,
	186, 187, 184, 185, 188, 189, 190, 191, 182, 183,
	175, 178, 180, 181, 179, 347, 0, 0, 0, 0,
	0, 193, 173, 177, 176, 0, 0, 0, 169, 171,
	170, 192, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 167, 168, 172, 174, 186, 187, 184,
	185, 188, 189, 190, 191, 182, 183, 175, 178, 180,
	181, 179, 346, 0, 0, 0, 0, 0, 193, 173,
	177, 176, 0, 0, 0, 169, 171, 170, 192, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	167, 168, 172, 174, 186, 187, 184, 185, 188, 189,
	190, 191, 182, 183, 175, 178, 180, 181, 179, 166,
	0, 0, 0, 0, 0, 193, 173, 177, 176, 668,
	666, 667, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 167, 168, 172,
	174, 186, 187, 184, 185, 188, 189, 190, 191, 182,
	183, 175, 178, 180, 181, 179, 0, 653, 0, 679,
	661, 655, 654, 169, 171, 170, 192, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 670, 669, 660, 662, 673, 674, 671, 672, 675,
	677, 676, 678, 663, 664, 665, 656, 658, 659, 657,
	0, 0, 0, 193, 173, 177, 176, 171, 170, 192,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 167, 168, 172, 174, 186,
	187, 184, 185, 188, 189, 190, 191, 182, 183, 175,
	178, 180, 181, 179, 0, 0, 193, 173, 177, 176,
	0, 667, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 167, 168,
	172, 174, 186, 187, 184, 185, 188, 189, 190, 191,
	182, 183, 175, 178, 180, 181, 179, 653, 0, 679,
	661, 655, 654, 170, 192, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 670, 669, 660, 662, 673, 674, 671, 672, 675,
	677, 676, 678, 663, 664, 665, 656, 658, 659, 657,
	0, 193, 173, 177, 176, 192, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 167, 168, 172, 174, 186, 187, 184,
	185, 188, 189, 190, 191, 182, 183, 175, 178, 180,
	181, 179, 193, 173, 177, 176, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 167, 168, 172, 174, 186, 187,
	184, 185, 188, 189, 190, 191, 182, 183, 175, 178,
	180, 181, 179, 653, 0, 679, 661, 655, 654, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 670, 669, 660,
	662, 673, 674, 671, 672, 675, 677, 676, 678, 663,
	664, 665, 656, 658, 659, 657, 653, 0, 0, 661,
	655, 654, 192, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	670, 669, 660, 662, 673, 674, 671, 672, 675, 677,
	676, 678, 663, 664, 665, 656, 658, 659, 657, 0,
	173, 177, 176, 0, 0, 0, 0, 83, 84, 72,
	0, 105, 106, 126, 88, 121, 0, 0, 0, 0,
	0, 95, 168, 172, 174, 186, 187, 184, 185, 188,
	189, 190, 191, 182, 183, 175, 178, 180, 181, 179,
	45, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 81, 82, 0, 0, 0, 0, 0, 0,
	0, 0, 52, 96, 0, 94, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 143, 113, 109, 103, 489, 85, 86, 87,
	0, 0, 0, 0, 80, 53, 0, 0, 0, 78,
	42, 149, 0, 0, 0, 0, 0, 55, 56, 0,
	65, 66, 67, 68, 69, 70, 71, 0, 0, 653,
	92, 77, 661, 655, 654, 0, 63, 482, 97, 0,
	0, 488, 58, 57, 59, 60, 73, 120, 0, 0,
	0, 0, 0, 0, 0, 660, 662, 673, 674, 671,
	672, 675, 677, 676, 678, 663, 664, 665, 656, 658,
	659, 657, 83, 84, 72, 0, 105, 106, 126, 88,
	121, 0, 0, 0, 0, 0, 95, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 45, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 81, 82, 0,
	0, 0, 0, 0, 0, 0, 0, 52, 96, 0,
	94, 110, 111, 112, 107, 108, 0, 0, 0, 0,
	0, 0, 93, 0, 192, 0, 0, 143, 113, 109,
	103, 489, 85, 86, 87, 0, 0, 0, 0, 80,
	53, 0, 0, 0, 78, 148, 149, 0, 0, 0,
	0, 0, 55, 56, 0, 65, 66, 67, 68, 69,
	70, 71, 173, 177, 176, 92, 77, 0, 0, 0,
	0, 63, 0, 97, 0, 0, 488, 58, 57, 59,
	60, 73, 120, 0, 0, 172, 174, 186, 187, 184,
	185, 188, 189, 190, 191, 182, 183, 175, 178, 180,
	181, 179, 83, 84, 72, 0, 105, 106, 126, 88,
	121, 0, 0, 0, 0, 0, 95, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 45, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 81, 82, 0,
	0, 0, 0, 0, 0, 0, 0, 52, 96, 0,
	94, 110, 111, 112, 107, 108, 0, 0, 0, 0,
	0, 0, 93, 0, 0, 0, 0, 143, 113, 109,
	103, 0, 85, 86, 87, 192, 0, 0, 0, 80,
	53, 0, 0, 0, 78, 148, 149, 0, 0, 0,
	0, 0, 55, 56, 0, 65, 66, 67, 68, 69,
	70, 71, 0, 0, 0, 92, 77, 0, 0, 0,
	0, 63, 0, 97, 177, 176, 866, 58, 57, 59,
	60, 73, 120, 83, 84, 72, 0, 105, 106, 126,
	88, 121, 0, 0, 0, 0, 0, 95, 186, 187,
	184, 185, 188, 189, 190, 191, 182, 183, 175, 178,
	180, 181, 179, 0, 0, 0, 45, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 81, 82,
	0, 0, 0, 0, 0, 0, 0, 0, 52, 96,
	0, 94, 110, 111, 112, 107, 108, 0, 0, 0,
	0, 0, 0, 93, 0, 0, 0, 0, 143, 113,
	109, 103, 0, 85, 86, 87, 0, 0, 0, 0,
	80, 53, 0, 0, 0, 78, 148, 149, 0, 0,
	0, 0, 0, 55, 56, 0, 65, 66, 67, 68,
	69, 70, 71, 0, 0, 0, 92, 77, 0, 0,
	0, 0, 63, 0, 97, 0, 0, 629, 58, 57,
	59, 60, 73, 120, 83, 84, 72, 0, 105, 106,
	126, 88, 121, 0, 0, 0, 0, 0, 95, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 45, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 81,
	82, 0, 0, 0, 0, 0, 0, 0, 0, 52,
	96, 0, 94, 110, 111, 112, 107, 108, 0, 0,
	0, 0, 0, 0, 93, 0, 192, 0, 0, 143,
	113, 109, 103, 0, 85, 86, 87, 0, 0, 0,
	0, 80, 53, 0, 0, 0, 78, 148, 149, 0,
	0, 0, 0, 0, 55, 56, 0, 65, 66, 67,
	68, 69, 70, 71, 173, 177, 176, 92, 77, 0,
	0, 0, 0, 63, 0, 97, 0, 0, 627, 58,
	57, 59, 60, 73, 120, 0, 0, 0, 174, 186,
	187, 184, 185, 188, 189, 190, 191, 182, 183, 175,
	178, 180, 181, 179, 83, 84, 72, 0, 105, 106,
	126, 88, 121, 0, 0, 0, 0, 0, 95, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 45, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 81,
	82, 0, 0, 0, 0, 0, 0, 0, 0, 52,
	96, 0, 94, 110, 111, 112, 107, 108, 0, 0,
	0, 0, 0, 0, 93, 0, 0, 0, 0, 143,
	113, 109, 103, 0, 85, 86, 87, 0, 0, 0,
	0, 80, 53, 0, 0, 0, 78, 148, 149, 0,
	0, 0, 0, 0, 55, 56, 0, 65, 66, 67,
	68, 69, 70, 71, 0, 0, 0, 92, 77, 0,
	0, 0, 0, 63, 0, 97, 0, 0, 292, 58,
	57, 59, 60, 73, 120, 83, 84, 72, 0, 105,
	106, 126, 88, 121, 0, 0, 0, 0, 0, 95,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 45, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	81, 82, 0, 0, 0, 0, 0, 0, 0, 0,
	52, 96, 0, 94, 110, 111, 112, 107, 108, 0,
	0, 0, 0, 0, 0, 93, 0, 0, 0, 0,
	143, 113, 109, 103, 0, 85, 86, 87, 0, 192,
	0, 0, 80, 53, 0, 0, 0, 78, 42, 149,
	0, 0, 0, 0, 0, 55, 56, 0, 65, 66,
	67, 68, 69, 70, 71, 0, 0, 0, 92, 77,
	0, 0, 0, 0, 63, 431, 97, 173, 177, 176,
	58, 57, 59, 60, 73, 120, 83, 84, 72, 0,
	105, 106, 126, 88, 121, 0, 0, 0, 0, 0,
	95, 0, 186, 187, 184, 185, 188, 189, 190, 191,
	182, 183, 175, 178, 180, 181, 179, 0, 0, 45,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 81, 82, 0, 0, 0, 0, 0, 0, 0,
	0, 52, 96, 0, 94, 110, 111, 112, 107, 108,
	0, 0, 0, 0, 0, 0, 93, 0, 0, 0,
	0, 143, 113, 109, 103, 0, 85, 86, 87, 0,
	0, 0, 0, 80, 53, 0, 0, 0, 78, 148,
	149, 0, 0, 0, 0, 0, 55, 56, 0, 65,
	66, 67, 68, 69, 70, 71, 0, 0, 0, 92,
	77, 0, 0, 0, 0, 63, 0, 97, 0, 0,
	407, 58, 57, 59, 60, 73, 120, 83, 84, 72,
	0, 105, 106, 126, 88, 121, 0, 0, 0, 0,
	0, 95, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	45, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 81, 82, 0, 0, 0, 0, 0, 0,
	0, 0, 52, 96, 0, 94, 110, 111, 112, 107,
	108, 0, 0, 0, 0, 0, 0, 93, 0, 0,
	0, 0, 143, 113, 109, 103, 0, 85, 86, 87,
	0, 0, 0, 0, 80, 53, 0, 0, 0, 78,
	148, 149, 0, 0, 0, 0, 0, 55, 56, 0,
	65, 66, 67, 68, 69, 70, 71, 0, 0, 0,
	92, 77, 0, 0, 0, 388, 63, 0, 97, 0,
	0, 0, 58, 57, 59, 60, 73, 120, 83, 84,
	72, 0, 105, 106, 126, 88, 121, 0, 0, 0,
	0, 0, 95, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 45, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 81, 82, 0, 0, 0, 0, 0,
	0, 0, 0, 52, 96, 0, 94, 110, 111, 112,
	107, 108, 0, 0, 0, 0, 0, 0, 93, 0,
	0, 0, 0, 143, 113, 109, 103, 0, 85, 86,
	87, 0, 0, 0, 0, 80, 53, 0, 0, 0,
	78, 148, 149, 0, 0, 0, 0, 0, 55, 56,
	0, 65, 66, 67, 68, 69, 70, 71, 0, 0,
	0, 92, 77, 0, 0, 152, 0, 63, 0, 97,
	0, 0, 0, 58, 57, 59, 60, 73, 120, 83,
	84, 72, 0, 105, 106, 126, 88, 121, 0, 0,
	0, 0, 0, 95, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 45, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 81, 82, 0, 0, 0, 0,
	0, 0, 0, 0, 52, 96, 0, 94, 110, 111,
	112, 107, 108, 0, 0, 0, 0, 0, 0, 93,
	0, 0, 0, 0, 143, 113, 109, 103, 0, 85,
	86, 87, 0, 0, 0, 0, 80, 53, 0, 0,
	0, 78, 148, 149, 0, 0, 0, 0, 0, 55,
	56, 0, 65, 66, 67, 68, 69, 70, 71, 0,
	0, 0, 92, 77, 0, 0, 150, 0, 63, 0,
	97, 0, 0, 0, 58, 57, 59, 60, 73, 120,
	83, 84, 72, 0, 105, 106, 126, 88, 121, 0,
	0, 0, 0, 0, 95, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 45, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 81, 82, 0, 0, 0,
	0, 0, 0, 0, 0, 52, 96, 0, 94, 110,
	111, 112, 107, 108, 0, 0, 0, 0, 0, 0,
	93, 0, 0, 0, 0, 143, 113, 109, 103, 0,
	85, 86, 87, 0, 0, 0, 0, 80, 53, 0,
	0, 0, 78, 148, 149, 0, 0, 0, 0, 0,
	55, 56, 0, 65, 66, 67, 68, 69, 70, 71,
	0, 0, 0, 92, 77, 0, 0, 146, 0, 63,
	0, 97, 0, 0, 0, 58, 57, 59, 60, 73,
	120, 83, 84, 72, 0, 105, 106, 126, 88, 121,
	0, 0, 0, 0, 0, 95, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 45, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 81, 82, 0, 0,
	0, 0, 0, 0, 0, 0, 52, 96, 0, 94,
	110, 111, 112, 107, 108, 0, 0, 0, 0, 0,
	0, 93, 0, 0, 0, 0, 143, 113, 109, 103,
	0, 85, 86, 87, 0, 0, 0, 0, 80, 53,
	0, 0, 0, 78, 148, 149, 0, 0, 0, 0,
	0, 55, 56, 0, 65, 66, 67, 68, 69, 70,
	71, 0, 0, 0, 92, 77, 0, 0, 0, 0,
	63, 0, 97, 0, 0, 0, 58, 57, 59, 60,
	73, 120, 83, 84, 72, 0, 105, 106, 126, 442,
	121, 0, 0, 0, 0, 0, 95, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 45, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 81, 82, 0,
	0, 0, 0, 0, 0, 0, 0, 52, 96, 0,
	94, 110, 111, 112, 107, 108, 0, 0, 0, 0,
	0, 0, 93, 0, 0, 0, 0, 143, 113, 109,
	103, 0, 85, 86, 87, 0, 0, 0, 0, 80,
	53, 0, 0, 0, 78, 148, 149, 0, 0, 0,
	0, 0, 55, 56, 0, 65, 66, 67, 68, 69,
	70, 71, 0, 0, 0, 92, 77, 0, 0, 0,
	0, 63, 0, 97, 0, 0, 0, 58, 57, 59,
	60, 73, 120, 83, 84, 72, 0, 105, 106, 126,
	88, 121, 0, 0, 0, 0, 0, 95, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 45, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 81, 82,
	0, 0, 0, 0, 0, 0, 0, 0, 52, 96,
	0, 94, 110, 111, 112, 107, 108, 0, 0, 0,
	0, 0, 0, 93, 0, 0, 0, 0, 143, 113,
	109, 103, 0, 85, 86, 87, 0, 0, 0, 0,
	80, 53, 105, 106, 126, 78, 42, 149, 0, 0,
	0, 0, 529, 55, 56, 0, 65, 66, 67, 68,
	69, 70, 71, 0, 0, 0, 92, 77, 0, 0,
	0, 0, 63, 0, 97, 0, 0, 0, 58, 57,
	59, 60, 73, 120, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 524, 0, 527, 110, 111, 112,
	107, 108, 0, 0, 0, 0, 0, 0, 530, 0,
	0, 0, 0, 522, 113, 109, 523, 105, 106, 126,
	0, 0, 0, 0, 0, 0, 0, 529, 0, 0,
	0, 0, 233, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 787, 536, 0, 525,
	0, 0, 0, 535, 534, 532, 533, 0, 0, 524,
	0, 527, 110, 111, 112, 107, 108, 0, 0, 0,
	0, 0, 0, 530, 0, 0, 0, 0, 522, 113,
	109, 523, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 233, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 536, 0, 525, 0, 0, 0, 535, 534,
	532, 533,
}
var yyPact = [...]int{

	-1000, -1000, 2286, -1000, -1000, -1000, -1000, -1000, 267, 471,
	610, 73, -1000, 269, -1000, -1000, 852, -1000, 209, 209,
	4934, 264, 209, 7826, 7695, 7564, 336, 163, 721, 7957,
	-1000, 5808, 263, 262, 261, -1000, 373, 7957, 850, 53,
	844, 843, 7957, -1000, -1000, -1000, -1000, 661, -1000, 659,
	-1000, 1185, 258, 7957, 402, 449, 449, 7957, 7957, 7957,
	7957, -1000, -1000, 8219, -1000, 7957, 7957, 7957, 7957, 7957,
	7957, 7957, 252, 7957, -1000, 170, 167, 891, 7957, 595,
	702, 250, 246, 7957, 7957, 245, 7957, 7957, -1000, 166,
	-1000, -1000, 887, 781, -1000, 165, 244, 7040, -1000, 159,
	156, -1000, 206, 808, 543, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, 103, 160, -1000, 537, 210, -1000,
	372, -1000, 199, 359, -1000, 808, -1000, 57, 571, 540,
	-1000, 621, 808, -1000, 842, -1000, -17, 4015, 4803, 8219,
	4672, 718, 53, 485, 7957, 255, -1000, 5761, -1000, 688,
	-1000, 5714, -1000, 333, 1259, 5896, -1000, 56, -1000, -1000,
	411, 45, 53, -18, 38, 5896, -1000, 7957, 7957, 7957,
	7957, 7957, 7957, 7957, 7957, 7957, 7957, 7957, 7957, 7957,
	7957, 7957, 7957, 7957, 7957, 7957, 7957, 7957, 7957, 7957,
	7957, 7957, 702, 7433, 449, 7957, 841, -1000, 5667, 332,
	286, -1000, 645, 639, -1000, 1185, 5620, -1000, -1000, 7302,
	7957, 7957, 7957, 7957, 7957, 7957, 7957, 7957, 7957, 7957,
	7957, 7957, 404, -1000, -1000, -1000, -1000, -1000, 206, 474,
	808, 536, 525, -1000, -1000, -115, -115, -47, -115, 196,
	5576, 195, -115, -115, -115, -115, -115, -115, -115, -1000,
	7171, -1000, -115, 7957, 7957, 376, 706, 684, -1000, 219,
	8088, 449, 6065, 67, 210, 524, -1000, 422, 445, 808,
	583, 103, 160, 513, 7957, 7957, 5896, 5896, 7957, 5896,
	5896, 7957, 532, 706, 697, -1000, 710, 7957, 7040, 145,
	30, 5532, 449, 7957, 7957, 839, -1000, 6323, 206, 55,
	7957, 7957, 103, 372, 68, -1000, 7957, 330, -1000, -1000,
	2146, 206, -1000, 613, 19, -1000, 609, 808, 7, -1000,
	606, 808, 838, 604, -27, 8379, -1000, -1000, -1000, -1000,
	-1000, -1000, 241, -1000, -1000, -1000, -1000, -1000, 209, 239,
	329, 20, 5896, -1000, 325, 324, -1000, -1000, -1000, -1000,
	-1000, 163, -1000, 7957, -1000, -1000, 784, 237, 8379, -1000,
	7957, 6192, 6464, 5939, 6065, 6024, 6876, 6625, 7169, 4,
	4, 4, -47, -115, -47, -47, 100, 100, 953, 953,
	953, 953, 863, 863, 863, 863, -1000, 5488, 7957, 3,
	-1000, -1000, 1121, 715, -3, -39, 3882, -1000, -1000, 228,
	519, 628, 563, 368, 563, 7957, 6065, 351, 6065, 6065,
	6065, 6065, 6065, 6065, 6065, 6065, 6065, 6065, 6065, 6065,
	-12, -1000, -1000, 224, 808, 206, 67, 67, 212, -1000,
	-1000, -1000, 142, 5896, 133, -1000, -1000, -1000, -1000, 803,
	836, 5442, 155, 342, 210, 164, -1000, -1000, 103, 160,
	-1000, 7957, -1000, -1000, 148, 808, 422, 67, 103, 148,
	-22, -1000, 1185, -1000, 1046, 193, 5394, 125, -1000, -1000,
	-1000, 107, 192, -1000, -1000, 6890, 6759, -1000, -1000, 106,
	99, -1000, -1000, -25, 189, -1000, -1000, 1185, 449, 7957,
	-1000, 210, 210, -1000, -1000, 93, 5350, 210, 210, -1000,
	5302, -1000, 1759, -1000, -1000, -1000, -1000, 571, 831, 522,
	-1000, 540, 830, 517, -1000, 825, 8379, -1000, 5852, -1000,
	-1000, 422, 443, 808, 216, 8379, -1000, -1000, -1000, -1000,
	615, 508, 8379, 8379, 8379, 8379, 8379, 188, 447, 4148,
	3749, 323, 7957, 7957, 399, -1000, 737, -1000, -1000, 5254,
	-40, 519, -1000, 5896, 7957, 4932, 322, 449, 1529, 1529,
	4541, 821, 8379, 687, 519, 187, -4, -1000, 53, -1000,
	-1000, -1000, 422, 436, 808, 365, 563, -1000, -1000, -29,
	-1000, -1000, 1185, -1000, 702, -43, 404, 404, 206, -1000,
	-1000, 161, 572, 7957, -1000, 67, -1000, -1000, 88, -1000,
	-1000, -1000, -1000, -1000, 7957, -1000, -1000, 154, 147, -1000,
	7957, 7957, 103, 5206, -1000, 422, -1000, -1000, -1000, 7957,
	-1000, -1000, -1000, -1000, -1000, -1000, 5158, 449, 5896, 449,
	-1000, -1000, -1000, 6478, -1000, -1000, 5896, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, -1000, -1000, -1000, 818, -1000, -1000,
	811, -1000, -1000, 8379, 8379, 8379, 8379, 8379, 8379, 8379,
	8379, 8379, 8379, 8379, 8379, 8379, 8379, 8379, 8379, 8379,
	8379, 8379, 8379, 8379, 8379, 8379, 8379, 8379, 8379, 8304,
	808, 422, 8379, 83, -11, 5114, 535, 714, -72, -72,
	-81, -81, 5070, 317, -1000, 209, 4934, 429, 316, -1000,
	315, 5896, -1000, 7957, 233, 396, 314, 709, -1000, 8379,
	186, 4932, -1000, -1000, 566, -1000, 449, 215, 566, -1000,
	-1000, -1000, -62, -1000, 679, 213, 184, 676, 519, 412,
	808, 422, -1000, -29, 1023, 563, 210, 7957, -1000, -32,
	7957, 572, -1000, 80, 210, -1000, 5026, 572, 7957, 7957,
	79, 4982, -1000, 570, -1000, 6628, -1000, -1000, -1000, -1000,
	-1000, 1911, -81, -81, -72, -72, -72, -72, 1333, 1788,
	82, 33, 33, -81, 5982, 6108, 1955, 6314, 1571, -14,
	-14, -14, -14, 91, 91, 91, 91, 8379, 1190, 422,
	183, -1000, -1000, 8379, 8379, -1000, -1000, -1000, -1000, 4934,
	-1000, 375, 209, 234, -1000, 7957, 1051, -1000, -1000, -1000,
	-1000, -1000, 303, -1000, 676, 182, 1529, -1000, 404, 180,
	3616, 8379, -1000, 363, 563, 358, 355, 207, -1000, 778,
	-1000, 422, 817, -1000, -1000, 767, -30, -1000, 688, 708,
	-1000, 802, 563, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	-1000, -1000, 6065, -1000, 77, -1000, -1000, 340, -1000, 62,
	59, -1000, -1000, -1000, 67, 5896, 449, -1000, 6151, 8379,
	-1000, 1807, 5852, -1000, 296, 220, -1000, 179, -1000, 4148,
	-1000, 352, 4410, -1000, -34, 4410, 294, -1000, -1000, 766,
	-1000, -1000, 172, -64, -1000, -46, -66, -1000, 793, 53,
	-1000, -67, -59, -1000, -1000, -1000, -1000, -1000, -1000, -1000,
	6151, 8379, -1000, -1000, 4148, 4279, 4148, -1000, -1000, -1000,
	-1000, -1000, -1000, -1000, 3483, 178, 3350, 3217, -37, -1000,
	744, 8379, -1000, 736, 8379, -70, 791, 8379, -1000, 563,
	-1000, 564, 5852, 4148, -1000, -1000, -1000, 3084, 2951, -1000,
	346, -1000, -1000, -1000, 171, -1000, -1000, -82, -1000, 8379,
	205, -1000, -1000, 338, 564, -1000, 292, 290, 670, 703,
	433, -1000, 2818, -1000, 273, -1000, -1000, 733, 8379, -1000,
	519, -1000, -1000, -1000, -1000, 563, 708, 789, 214, -1000,
	2685, -1000, -1000, 177, -80, -1000, 787, -1000, -1000, -1000,
	685, 281, 563, -1000, -1000, 685, -1000, 202, -1000, -1000,
	-1000, -1000, -1000, 563, 2552, 723, -1000, 58, 345, -1000,
	2419, -1000,
}
var yyPgo = [...]int{

	0, 29, 1091, 1090, 38, 31, 30, 572, 1088, 1086,
	134, 217, 204, 88, 1385, 82, 63, 59, 651, 1422,
	1085, 33, 1081, 1080, 1079, 136, 1078, 36, 37, 1077,
	1076, 1075, 1074, 135, 1073, 1072, 24, 1069, 26, 48,
	45, 1068, 634, 34, 1066, 1, 1065, 1063, 27, 1062,
	73, 68, 61, 1060, 1059, 1058, 35, 1057, 1056, 4,
	1055, 1054, 1053, 17, 1051, 1049, 1048, 1047, 1046, 51,
	5, 1045, 1042, 1041, 1040, 1037, 2, 1033, 631, 1032,
	39, 0, 1018, 1017, 1013, 117, 1007, 1001, 513, 1000,
	998, 42, 8, 995, 9, 991, 990, 988, 14, 49,
	985, 983, 982, 980, 976, 974, 3, 971, 16, 962,
	961, 959, 958, 955, 28, 952, 951, 950, 949, 948,
	947, 945, 21, 939, 933, 930, 25, 929, 23, 12,
	928, 40, 924, 923, 922, 914, 41, 6, 19, 18,
	22, 911, 907, 902, 13, 869, 866, 865, 15, 863,
	7, 20,
}
var yyR1 = [...]int{

	0, 149, 80, 80, 81, 81, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 82, 82,
	4, 4, 4, 4, 83, 83, 5, 5, 5, 5,
	84, 84, 6, 6, 6, 6, 53, 53, 85, 85,
	24, 24, 24, 24, 24, 25, 25, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 26, 26, 26, 26, 26,
	26, 26, 26, 26, 26, 103, 103, 58, 58, 104,
	104, 105, 105, 59, 101, 101, 56, 51, 52, 144,
	144, 145, 145, 60, 61, 61, 64, 64, 64, 64,
	65, 65, 2, 113, 113, 109, 109, 114, 114, 138,
	138, 137, 137, 137, 147, 147, 148, 148, 57, 57,
	102, 102, 141, 141, 141, 141, 99, 99, 99, 150,
	150, 146, 146, 95, 95, 96, 96, 54, 54, 55,
	55, 106, 106, 107, 107, 63, 63, 62, 62, 62,
	62, 140, 140, 140, 115, 115, 69, 69, 69, 69,
	86, 86, 27, 27, 27, 87, 87, 87, 87, 108,
	108, 66, 66, 66, 66, 68, 116, 116, 143, 143,
	117, 117, 118, 118, 70, 70, 71, 119, 119, 74,
	74, 73, 72, 72, 75, 75, 142, 142, 110, 110,
	111, 111, 120, 120, 76, 76, 76, 76, 76, 76,
	112, 112, 112, 112, 67, 67, 100, 100, 98, 98,
	97, 97, 126, 126, 124, 124, 125, 125, 125, 127,
	127, 42, 15, 15, 15, 15, 15, 15, 15, 15,
	15, 15, 15, 15, 15, 15, 15, 15, 15, 15,
	15, 15, 15, 15, 15, 15, 15, 15, 15, 15,
	15, 15, 15, 15, 15, 15, 15, 15, 15, 15,
	15, 15, 15, 15, 15, 15, 15, 15, 15, 15,
	15, 15, 15, 15, 15, 15, 15, 15, 15, 15,
	15, 15, 15, 15, 15, 15, 15, 15, 15, 15,
	15, 15, 15, 15, 15, 15, 50, 50, 50, 50,
	47, 47, 47, 47, 46, 46, 1, 94, 94, 93,
	93, 93, 93, 23, 23, 23, 23, 23, 23, 23,
	23, 11, 11, 11, 11, 45, 45, 45, 43, 43,
	41, 41, 134, 134, 133, 49, 49, 49, 121, 121,
	121, 139, 139, 7, 7, 7, 7, 7, 7, 7,
	7, 7, 7, 7, 7, 8, 28, 78, 78, 78,
	78, 78, 78, 78, 78, 78, 78, 79, 79, 79,
	79, 79, 79, 79, 79, 79, 79, 79, 79, 79,
	79, 79, 79, 79, 79, 79, 79, 79, 79, 79,
	79, 79, 79, 79, 79, 79, 79, 79, 79, 79,
	35, 35, 35, 35, 29, 29, 29, 29, 29, 29,
	29, 122, 122, 151, 151, 123, 123, 123, 123, 14,
	14, 48, 48, 16, 17, 18, 19, 19, 135, 135,
	128, 130, 130, 77, 129, 129, 129, 40, 40, 44,
	44, 12, 22, 22, 20, 20, 20, 21, 21, 21,
	10, 10, 10, 9, 9, 13, 13, 131, 131, 132,
	132, 132, 39, 39, 136, 136, 92, 92, 38, 38,
	38, 91, 91, 90, 90, 90, 90, 90, 90, 90,
	90, 88, 88, 88, 88, 33, 33, 33, 33, 33,
	33, 34, 34, 34, 37, 37, 37, 37, 37, 37,
	37, 37, 89, 89, 36, 36, 30, 30, 31, 32,
}
var yyR2 = [...]int{

	0, 1, 2, 0, 1, 3, 1, 1, 1, 1,
	4, 3, 5, 4, 3, 4, 4, 2, 3, 1,
	1, 3, 2, 4, 3, 1, 1, 3, 2, 4,
	3, 1, 1, 3, 2, 4, 5, 4, 2, 0,
	1, 1, 1, 1, 4, 1, 2, 3, 5, 8,
	3, 5, 9, 3, 2, 3, 2, 3, 2, 3,
	3, 2, 3, 3, 3, 1, 2, 5, 8, 8,
	5, 1, 6, 3, 3, 0, 9, 0, 4, 1,
	0, 1, 2, 8, 1, 3, 1, 1, 1, 0,
	1, 0, 1, 9, 7, 6, 1, 2, 1, 2,
	0, 2, 1, 0, 2, 0, 2, 1, 3, 0,
	2, 1, 2, 4, 1, 4, 1, 4, 1, 4,
	3, 5, 3, 4, 4, 5, 0, 5, 4, 1,
	1, 1, 4, 0, 4, 0, 5, 0, 2, 0,
	3, 1, 0, 1, 3, 4, 6, 0, 1, 1,
	1, 2, 3, 3, 1, 3, 1, 1, 2, 2,
	3, 1, 1, 2, 4, 3, 5, 1, 3, 2,
	0, 3, 2, 1, 8, 3, 1, 3, 1, 3,
	0, 1, 1, 2, 2, 2, 3, 1, 3, 1,
	1, 3, 4, 3, 0, 1, 1, 3, 1, 1,
	0, 1, 1, 2, 1, 1, 1, 1, 1, 1,
	3, 5, 1, 3, 5, 4, 3, 1, 0, 1,
	3, 1, 2, 1, 4, 3, 2, 1, 1, 0,
	1, 3, 6, 3, 4, 6, 2, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 2,
	2, 2, 2, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	2, 2, 2, 2, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 1, 1, 4, 5, 4, 1, 2,
	2, 2, 2, 2, 2, 2, 2, 2, 1, 1,
	1, 3, 2, 1, 9, 10, 2, 2, 4, 4,
	4, 4, 4, 4, 4, 3, 1, 0, 4, 3,
	4, 1, 2, 2, 4, 3, 4, 4, 4, 4,
	2, 1, 1, 3, 2, 1, 3, 2, 1, 1,
	4, 1, 2, 0, 2, 0, 2, 1, 0, 1,
	1, 0, 1, 1, 1, 1, 1, 1, 1, 1,
	1, 1, 1, 3, 2, 3, 1, 1, 1, 1,
	3, 2, 4, 3, 1, 1, 1, 4, 3, 3,
	3, 3, 3, 3, 2, 2, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 4, 5, 2, 2, 3,
	1, 1, 3, 2, 1, 1, 1, 1, 3, 3,
	1, 0, 2, 0, 1, 5, 3, 3, 1, 1,
	1, 3, 3, 1, 1, 1, 5, 1, 2, 0,
	3, 4, 4, 1, 1, 1, 0, 1, 2, 3,
	3, 1, 4, 4, 1, 1, 1, 1, 2, 1,
	4, 4, 1, 1, 4, 0, 1, 1, 1, 4,
	4, 1, 1, 3, 1, 2, 3, 1, 1, 4,
	0, 0, 2, 5, 3, 3, 1, 6, 4, 4,
	2, 2, 2, 1, 2, 1, 4, 3, 3, 6,
	3, 1, 1, 1, 4, 4, 4, 2, 2, 4,
	2, 2, 1, 3, 1, 1, 3, 3, 3, 3,
}
var yyChk = [...]int{

	-1000, -149, -80, -3, 2, -25, -51, -52, 51, 79,
	44, -53, -26, 10, -60, -61, 38, 119, 7, 21,
	20, 23, 30, 34, 35, 39, -50, 46, 98, 19,
	14, -14, 48, 25, 27, 121, 40, 43, 36, -1,
	-64, -2, 97, -16, -15, 37, 52, 99, 53, 100,
	54, -19, 59, 92, -18, 104, 105, 130, 129, 131,
	132, -48, -42, 123, -37, 107, 108, 109, 110, 111,
	112, 113, 6, 133, -29, -47, -46, 118, 96, -20,
	91, 49, 50, 4, 5, 84, 85, 86, 11, -35,
	-32, -7, 117, 74, 62, 18, 60, 125, -21, -22,
	-23, -30, -81, 82, -11, 8, 9, 66, 67, 81,
	63, 64, 65, 80, -10, -136, -44, -12, -40, -9,
	134, 12, 123, -81, 119, 82, 10, -82, 37, 38,
	-4, -81, 82, 121, 135, 122, 10, -85, -48, 123,
	-48, -25, -1, 79, 123, -48, 121, -14, 97, 98,
	121, -14, 121, -15, -19, -14, 121, -86, -27, 12,
	134, -87, -1, 12, -100, -14, 121, 149, 150, 87,
	89, 88, 151, 128, 152, 163, 130, 129, 164, 167,
	165, 166, 161, 162, 155, 156, 153, 154, 157, 158,
	159, 160, 90, 127, 123, 123, 123, 119, -14, 10,
	-144, 128, 10, 10, -15, -19, -14, 52, 52, 136,
	137, 138, 139, 148, 140, 141, 142, 143, 144, 145,
	146, 147, 123, -14, 104, 105, -18, -19, -81, 79,
	82, -11, -12, 98, -18, -14, -14, -14, -14, -42,
	-14, -50, -14, -14, -14, -14, -14, -14, -14, -49,
	123, -48, -14, 125, 125, -121, 17, -88, -33, 12,
	76, 77, -14, 57, -43, -11, -41, -81, 79, 82,
	-21, -10, -136, -12, 123, 123, -14, -14, 123, -14,
	-14, 125, -88, 17, 17, 75, -88, 125, 123, -91,
	-90, -14, 128, 125, 125, 82, -140, 123, -81, 78,
	125, 119, -10, 134, 78, -140, 119, 124, 121, 119,
	-80, -81, 121, 135, -83, -5, -81, 82, -84, -6,
	-81, 82, 29, -81, 10, 136, -24, 120, 2, -25,
	-51, -52, 51, -25, 122, -146, -25, 122, 21, -144,
	-98, -97, -14, -141, 119, 122, 121, 121, 121, 121,
	121, 135, -16, 119, -19, 121, 135, -144, 136, 121,
	135, -14, -14, -14, -14, -14, -14, -14, -14, -14,
	-14, -14, -14, -14, -14, -14, -14, -14, -14, -14,
	-14, -14, -14, -14, -14, -14, -43, -14, 122, -101,
	-56, -19, -19, -15, -102, 10, -85, 121, 121, 10,
	123, -65, 55, -113, 55, 58, -14, 128, -14, -14,
	-14, -14, -14, -14, -14, -14, -14, -14, -14, -14,
	-92, -38, -19, 59, 82, -81, 78, 78, 124, 124,
	124, 124, -13, -14, -13, 118, -33, -33, 17, 125,
	57, -14, 11, -19, -131, -132, -40, -39, -10, -136,
	10, 119, -139, -140, 78, 82, -81, 57, -10, 78,
	-89, -36, -19, -15, -19, -15, -14, -13, 117, 75,
	75, -13, -91, 126, -151, 135, 58, -17, -19, -13,
	-13, 10, 124, -115, -50, -69, -15, -19, 128, 83,
	-140, -39, -40, 10, 52, -13, -14, -39, -40, 10,
	-14, 121, -80, 120, -140, -4, 121, 135, 29, -81,
	121, 135, 29, -81, 10, 29, 136, -28, -78, -7,
	-31, -81, 79, 82, 60, 125, -8, 62, -79, 18,
	74, -11, 131, 132, 130, 129, 123, 123, -95, -85,
	-85, -48, 121, 135, -99, 121, -99, 121, -27, -14,
	12, 123, -28, -14, 122, -14, 124, 135, 29, 29,
	124, 135, 136, 120, 123, -106, -107, -63, -62, 60,
	61, -45, -81, 79, 82, -109, 56, -45, 119, -114,
	-45, -15, -19, -19, 91, 124, 135, 123, -81, -127,
	-125, -124, -126, 125, -128, 57, 126, 126, -34, 10,
	13, 12, 10, 120, 125, 120, -129, -77, -130, -140,
	125, 119, -10, -14, -40, -81, -131, -40, 124, 135,
	124, 124, 124, 126, 126, 124, -14, 128, -14, 128,
	126, 126, 124, 135, 124, -17, -14, -140, -140, 126,
	120, -140, -140, 120, 120, -5, 10, 29, -6, 10,
	29, 10, -28, 125, 130, 129, 164, 167, 165, 166,
	151, 128, 152, 161, 162, 163, 88, 89, 87, 150,
	149, 155, 156, 153, 154, 157, 159, 158, 160, 127,
	82, -81, 123, -122, -123, -78, 17, 78, -78, -78,
	-78, -78, -78, 124, -54, 93, 94, -96, 22, 121,
	-98, -14, 120, 32, 33, -99, 31, -99, 120, 136,
	-106, -14, 121, -56, -137, -19, 128, 59, -137, -57,
	-25, 122, 10, -28, -103, 41, -106, 124, 135, -144,
	82, -81, 119, -114, -108, 135, -43, 136, -38, -92,
	125, -126, -128, -13, -131, 126, -14, -135, 125, 125,
	-13, -14, 120, -134, -36, 58, -17, -17, -69, 10,
	10, -78, -78, -78, -78, -78, -78, -78, -78, -78,
	-78, -78, -78, -78, -78, -78, -78, -78, -78, -78,
	-78, -78, -78, -78, -78, -78, -78, 122, -78, -81,
	-122, 126, -151, 135, 58, 10, 52, 124, 121, -48,
	-25, -55, 93, 94, 121, 121, -14, -150, 122, 121,
	120, 121, 31, -28, 124, -138, 58, -19, 123, -138,
	-85, 136, -58, 42, 123, 124, -94, 44, -63, -145,
	83, -81, -108, 120, -66, -110, -67, -68, -111, -120,
	47, 38, 44, -76, 103, 102, 101, 98, 99, 100,
	-45, -139, -14, 124, -13, 126, -129, 126, -128, -13,
	-13, 126, 120, -133, 57, -14, 128, 126, -78, 122,
	124, -78, -78, -25, 95, -48, 122, -98, -150, -85,
	121, -94, 124, -137, -92, 124, 28, -28, 119, -45,
	119, 119, 123, 12, 120, -112, 12, 121, 135, -1,
	-76, 10, -116, -45, 126, 120, 126, 126, -131, -17,
	-78, 58, 121, 122, -85, 124, -85, 119, -148, -25,
	122, 124, -148, 121, -85, 12, -85, -85, -93, 12,
	128, 136, 121, 135, 136, 10, -144, 136, -143, 135,
	121, 119, -78, -85, -147, -25, 122, -85, -85, 120,
	124, 120, 120, 124, 135, 12, -28, 12, -28, 136,
	10, -28, -45, -117, -118, -70, -71, -72, -73, -74,
	-45, 10, -85, 120, 26, 119, 12, 128, 136, -28,
	123, 120, -70, 121, 121, 45, 29, 78, 24, 121,
	-85, 12, -28, -106, -119, -45, -75, -76, 10, 121,
	120, 124, 135, 10, -104, -105, -59, 41, -142, 121,
	119, -45, -59, 123, -85, -45, 120, 12, 124, 119,
	-85, 120,
}
var yyDef = [...]int{

	3, -2, -2, 2, 6, 7, 8, 9, 0, 0,
	0, 0, 45, 4, 87, 88, 0, 39, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 331, 0,
	65, 0, 0, 0, 0, 71, 0, 0, 0, 89,
	0, 0, 303, 429, 430, 316, 96, 0, 98, 0,
	102, -2, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 283, 284, 0, 288, 0, 0, 0, 0, 0,
	0, 0, 345, 0, 298, 299, 300, 348, 0, 437,
	0, 0, 0, 0, 0, 0, 0, 0, 414, 415,
	416, 417, 0, 0, 420, 355, 0, 481, 454, 455,
	456, 410, -2, 0, 0, 353, 354, 356, 357, 358,
	359, 360, 361, 362, -2, 0, 459, 0, 0, 462,
	474, 463, 0, 0, 3, 0, 4, 0, 0, 0,
	19, 20, 0, 17, 0, 46, 0, 0, 0, 0,
	0, 0, 89, 0, 218, 0, 54, 0, 303, 331,
	56, 0, 58, 430, -2, 0, 61, 0, 161, 162,
	0, 0, 89, 167, 0, 217, 66, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 39, 0, 0,
	0, 90, 100, 103, -2, -2, 0, 97, 99, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 480, 236, 249, 251, 250, 435, 332, 0,
	0, 0, 0, 331, 252, 270, 271, 272, 273, 284,
	0, 0, 289, 290, 291, 292, 293, 294, 295, 296,
	0, 347, 297, 465, 465, 0, 349, 350, 493, 495,
	0, 0, 302, 0, 351, 338, 339, 332, 0, 0,
	341, -2, 0, 0, 0, 0, 507, 508, 0, 510,
	511, 465, 0, 0, 0, 364, 0, 465, 481, 0,
	423, 486, 0, 465, 465, 0, 323, 0, -2, 0,
	465, 0, -2, 475, 0, 330, 0, 0, 11, 3,
	0, -2, 14, 0, 0, 25, 26, 0, 0, 31,
	32, 0, 0, 22, 0, 0, 38, 47, 40, 41,
	42, 43, 0, 133, 39, 50, 131, 39, 0, 0,
	0, 219, 221, 53, 126, 126, 55, 57, 59, 60,
	62, 0, 163, 0, 433, 63, 0, 0, 0, 64,
	0, 253, 254, 255, 256, 257, 258, 259, 260, 261,
	262, 263, 264, 265, 266, 267, 268, 269, -2, -2,
	-2, -2, -2, -2, -2, -2, 282, 0, 0, 0,
	84, 86, -2, 430, 0, 0, 0, 73, 74, 0,
	-2, 105, 0, 0, 0, 0, 233, 0, 237, 238,
	239, 240, 241, 242, 243, 244, 245, 246, 247, 248,
	0, 477, 478, 0, 0, 334, 0, 0, 229, 431,
	432, 346, 0, 466, 0, 301, 494, 491, 492, 0,
	0, 0, 414, 0, 446, 467, 468, 471, 447, 0,
	472, 0, 231, 352, 0, 0, 334, 0, 458, 0,
	0, 512, -2, -2, -2, 430, 0, 0, 418, 363,
	419, 0, 0, 315, 482, 424, 0, 490, 434, 0,
	0, 5, 151, 0, 0, 154, -2, -2, 0, 0,
	325, 0, 449, -2, 519, 0, 0, 0, 450, -2,
	0, 10, 0, 13, 324, 18, 15, 0, 0, 28,
	16, 0, 0, 34, 21, 0, 0, 37, 366, 367,
	368, -2, 0, 0, 0, 421, 374, 375, 376, 355,
	0, 0, 0, 0, 0, 0, 0, 0, 137, -2,
	0, 0, 218, 0, 0, 126, 0, 126, 160, 0,
	165, -2, 168, 216, 0, 287, 0, 0, 0, 0,
	0, 0, 0, 75, -2, 0, 141, 143, 89, 148,
	149, 150, 335, 0, 0, 0, 0, 101, 170, 104,
	107, -2, -2, 234, 0, 0, 480, 480, 333, 285,
	230, 227, 228, 465, 223, 0, 311, 310, 0, 501,
	502, 503, 497, 498, 0, 500, 439, 444, 445, 443,
	465, 0, 448, 0, 449, 333, 343, 450, 504, 0,
	505, 506, 509, 313, 312, 314, 484, 0, 485, 0,
	452, 453, 152, 0, 153, 158, 159, 326, 327, 460,
	461, 328, 329, 464, 12, 24, 27, 0, 30, 33,
	0, 23, 36, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, 0, 0, 0, 0, 0, 0, 0, 0, 0,
	0, -2, 421, 0, 423, 428, 0, 0, 384, 385,
	407, 408, 0, 0, 48, 0, 0, 139, 0, 51,
	0, 220, 122, 0, 0, 0, 0, 0, 164, 0,
	0, 286, 67, 85, 109, 111, 0, 0, 109, 70,
	118, 39, 0, 120, 77, 0, 0, 317, 147, 91,
	0, 337, 170, 106, 200, 0, 351, 0, 476, 0,
	465, 226, 222, 0, 446, 496, 0, 436, 465, 465,
	0, 0, 473, 340, 513, 0, 488, 489, 155, 29,
	35, 0, 378, 379, 380, 381, 382, 383, 386, 387,
	388, 389, 390, 391, 392, 393, 394, 395, 396, -2,
	-2, -2, -2, -2, -2, -2, -2, 0, 0, -2,
	0, 373, 422, 424, 0, 365, 518, 409, 44, 0,
	138, 0, 0, 0, 132, 218, 0, 39, 129, 130,
	123, 124, 0, 166, 317, 0, 0, 112, 480, 0,
	0, 0, 72, 0, 0, 0, 0, 0, 144, 0,
	92, 336, 200, 95, 169, 0, 0, 173, 0, -2,
	199, 0, 0, 202, 204, 205, 206, 207, 208, 209,
	108, 235, 232, 479, 0, 225, 440, 0, 438, 0,
	0, 469, 470, 342, 0, 483, 0, 377, 405, 0,
	372, 426, 427, 134, 0, 0, 39, 0, 39, -2,
	125, 0, 0, 110, 0, 0, 0, 121, 39, 0,
	39, 39, 0, 145, 94, 0, 212, 172, 0, 89,
	203, 0, 0, 176, 224, 499, 442, 441, 344, 487,
	406, 0, 49, 39, -2, 0, -2, 39, 68, 116,
	39, 113, 69, 119, 0, 0, 0, 0, 0, 321,
	0, 0, 171, 0, 0, 0, 0, 0, 175, 0,
	178, 180, 425, -2, 52, 114, 39, 0, 0, 78,
	0, 93, 304, 318, 0, 322, 146, 210, 213, 0,
	0, 215, 177, 0, 181, 182, 0, 0, 190, 0,
	0, -2, 0, 305, 0, 39, 319, 0, 0, 214,
	-2, 179, 183, 184, 185, 0, 194, 0, 0, 117,
	0, 320, 211, 0, 186, 187, 0, -2, 191, 115,
	80, 0, 0, 192, 76, 79, 81, 0, 174, 196,
	39, 188, 82, 0, 0, 0, 197, 0, 0, 39,
	0, 83,
}
var yyTok1 = [...]int{

	1, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 131, 117, 3, 134, 166, 128, 3,
	123, 124, 164, 130, 135, 129, 163, 165, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 122, 121,
	157, 136, 159, 127, 133, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 125, 3, 126, 152, 3, 118, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 3, 3, 3, 3, 3, 3, 3,
	3, 3, 3, 119, 151, 120, 132,
}
var yyTok2 = [...]int{

	2, 3, 4, 5, 6, 7, 8, 9, 10, 11,
	12, 13, 14, 15, 16, 17, 18, 19, 20, 21,
	22, 23, 24, 25, 26, 27, 28, 29, 30, 31,
	32, 33, 34, 35, 36, 37, 38, 39, 40, 41,
	42, 43, 44, 45, 46, 47, 48, 49, 50, 51,
	52, 53, 54, 55, 56, 57, 58, 59, 60, 61,
	62, 63, 64, 65, 66, 67, 68, 69, 70, 71,
	72, 73, 74, 75, 76, 77, 78, 79, 80, 81,
	82, 83, 84, 85, 86, 87, 88, 89, 90, 91,
	92, 93, 94, 95, 96, 97, 98, 99, 100, 101,
	102, 103, 104, 105, 106, 107, 108, 109, 110, 111,
	112, 113, 114, 115, 116, 137, 138, 139, 140, 141,
	142, 143, 144, 145, 146, 147, 148, 149, 150, 153,
	154, 155, 156, 158, 160, 161, 162, 167,
}
var yyTok3 = [...]int{
	0,
}

var yyErrorMessages = [...]struct {
	state int
	token int
	msg   string
}{}

//line yaccpar:1

/*	parser for yacc output	*/

var (
	yyDebug        = 0
	yyErrorVerbose = false
)

type yyLexer interface {
	Lex(lval *yySymType) int
	Error(s string)
}

type yyParser interface {
	Parse(yyLexer) int
	Lookahead() int
}

type yyParserImpl struct {
	lval  yySymType
	stack [yyInitialStackSize]yySymType
	char  int
}

func (p *yyParserImpl) Lookahead() int {
	return p.char
}

func yyNewParser() yyParser {
	return &yyParserImpl{}
}

const yyFlag = -1000

func yyTokname(c int) string {
	if c >= 1 && c-1 < len(yyToknames) {
		if yyToknames[c-1] != "" {
			return yyToknames[c-1]
		}
	}
	return __yyfmt__.Sprintf("tok-%v", c)
}

func yyStatname(s int) string {
	if s >= 0 && s < len(yyStatenames) {
		if yyStatenames[s] != "" {
			return yyStatenames[s]
		}
	}
	return __yyfmt__.Sprintf("state-%v", s)
}

func yyErrorMessage(state, lookAhead int) string {
	const TOKSTART = 4

	if !yyErrorVerbose {
		return "syntax error"
	}

	for _, e := range yyErrorMessages {
		if e.state == state && e.token == lookAhead {
			return "syntax error: " + e.msg
		}
	}

	res := "syntax error: unexpected " + yyTokname(lookAhead)

	// To match Bison, suggest at most four expected tokens.
	expected := make([]int, 0, 4)

	// Look for shiftable tokens.
	base := yyPact[state]
	for tok := TOKSTART; tok-1 < len(yyToknames); tok++ {
		if n := base + tok; n >= 0 && n < yyLast && yyChk[yyAct[n]] == tok {
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}
	}

	if yyDef[state] == -2 {
		i := 0
		for yyExca[i] != -1 || yyExca[i+1] != state {
			i += 2
		}

		// Look for tokens that we accept or reduce.
		for i += 2; yyExca[i] >= 0; i += 2 {
			tok := yyExca[i]
			if tok < TOKSTART || yyExca[i+1] == 0 {
				continue
			}
			if len(expected) == cap(expected) {
				return res
			}
			expected = append(expected, tok)
		}

		// If the default action is to accept or reduce, give up.
		if yyExca[i+1] != 0 {
			return res
		}
	}

	for i, tok := range expected {
		if i == 0 {
			res += ", expecting "
		} else {
			res += " or "
		}
		res += yyTokname(tok)
	}
	return res
}

func yylex1(lex yyLexer, lval *yySymType) (char, token int) {
	token = 0
	char = lex.Lex(lval)
	if char <= 0 {
		token = yyTok1[0]
		goto out
	}
	if char < len(yyTok1) {
		token = yyTok1[char]
		goto out
	}
	if char >= yyPrivate {
		if char < yyPrivate+len(yyTok2) {
			token = yyTok2[char-yyPrivate]
			goto out
		}
	}
	for i := 0; i < len(yyTok3); i += 2 {
		token = yyTok3[i+0]
		if token == char {
			token = yyTok3[i+1]
			goto out
		}
	}

out:
	if token == 0 {
		token = yyTok2[1] /* unknown char */
	}
	if yyDebug >= 3 {
		__yyfmt__.Printf("lex %s(%d)\n", yyTokname(token), uint(char))
	}
	return char, token
}

func yyParse(yylex yyLexer) int {
	return yyNewParser().Parse(yylex)
}

func (yyrcvr *yyParserImpl) Parse(yylex yyLexer) int {
	var yyn int
	var yyVAL yySymType
	var yyDollar []yySymType
	_ = yyDollar // silence set and not used
	yyS := yyrcvr.stack[:]

	Nerrs := 0   /* number of errors */
	Errflag := 0 /* error recovery flag */
	yystate := 0
	yyrcvr.char = -1
	yytoken := -1 // yyrcvr.char translated into internal numbering
	defer func() {
		// Make sure we report no lookahead when not parsing.
		yystate = -1
		yyrcvr.char = -1
		yytoken = -1
	}()
	yyp := -1
	goto yystack

ret0:
	return 0

ret1:
	return 1

yystack:
	/* put a state and value onto the stack */
	if yyDebug >= 4 {
		__yyfmt__.Printf("char %v in %v\n", yyTokname(yytoken), yyStatname(yystate))
	}

	yyp++
	if yyp >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyS[yyp] = yyVAL
	yyS[yyp].yys = yystate

yynewstate:
	yyn = yyPact[yystate]
	if yyn <= yyFlag {
		goto yydefault /* simple state */
	}
	if yyrcvr.char < 0 {
		yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
	}
	yyn += yytoken
	if yyn < 0 || yyn >= yyLast {
		goto yydefault
	}
	yyn = yyAct[yyn]
	if yyChk[yyn] == yytoken { /* valid shift */
		yyrcvr.char = -1
		yytoken = -1
		yyVAL = yyrcvr.lval
		yystate = yyn
		if Errflag > 0 {
			Errflag--
		}
		goto yystack
	}

yydefault:
	/* default state action */
	yyn = yyDef[yystate]
	if yyn == -2 {
		if yyrcvr.char < 0 {
			yyrcvr.char, yytoken = yylex1(yylex, &yyrcvr.lval)
		}

		/* look through exception table */
		xi := 0
		for {
			if yyExca[xi+0] == -1 && yyExca[xi+1] == yystate {
				break
			}
			xi += 2
		}
		for xi += 2; ; xi += 2 {
			yyn = yyExca[xi+0]
			if yyn < 0 || yyn == yytoken {
				break
			}
		}
		yyn = yyExca[xi+1]
		if yyn < 0 {
			goto ret0
		}
	}
	if yyn == 0 {
		/* error ... attempt to resume parsing */
		switch Errflag {
		case 0: /* brand new error */
			yylex.Error(yyErrorMessage(yystate, yytoken))
			Nerrs++
			if yyDebug >= 1 {
				__yyfmt__.Printf("%s", yyStatname(yystate))
				__yyfmt__.Printf(" saw %s\n", yyTokname(yytoken))
			}
			fallthrough

		case 1, 2: /* incompletely recovered error ... try again */
			Errflag = 3

			/* find a state where "error" is a legal shift action */
			for yyp >= 0 {
				yyn = yyPact[yyS[yyp].yys] + yyErrCode
				if yyn >= 0 && yyn < yyLast {
					yystate = yyAct[yyn] /* simulate a shift of "error" */
					if yyChk[yystate] == yyErrCode {
						goto yystack
					}
				}

				/* the current p has no shift on "error", pop stack */
				if yyDebug >= 2 {
					__yyfmt__.Printf("error recovery pops state %d\n", yyS[yyp].yys)
				}
				yyp--
			}
			/* there is no state on the stack with an error shift ... abort */
			goto ret1

		case 3: /* no shift yet; clobber input char */
			if yyDebug >= 2 {
				__yyfmt__.Printf("error recovery discards %s\n", yyTokname(yytoken))
			}
			if yytoken == yyEofCode {
				goto ret1
			}
			yyrcvr.char = -1
			yytoken = -1
			goto yynewstate /* try again in the same state */
		}
	}

	/* reduction by production yyn */
	if yyDebug >= 2 {
		__yyfmt__.Printf("reduce %v in:\n\t%v\n", yyn, yyStatname(yystate))
	}

	yynt := yyn
	yypt := yyp
	_ = yypt // guard against "declared and not used"

	yyp -= yyR2[yyn]
	// yyp is now the index of $0. Perform the default action. Iff the
	// reduced production is ε, $1 is possibly out of range.
	if yyp+1 >= len(yyS) {
		nyys := make([]yySymType, len(yyS)*2)
		copy(nyys, yyS)
		yyS = nyys
	}
	yyVAL = yyS[yyp+1]

	/* consult goto table to find next state */
	yyn = yyR1[yyn]
	yyg := yyPgo[yyn]
	yyj := yyg + yyS[yyp].yys + 1

	if yyj >= yyLast {
		yystate = yyAct[yyg]
	} else {
		yystate = yyAct[yyj]
		if yyChk[yystate] != -yyn {
			yystate = yyAct[yyg]
		}
	}
	// dummy call; replaced with literal code
	switch yynt {

	case 1:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:236
		{
			yylex.(*Parser).rootNode = stmt.NewStmtList(yyDollar[1].list)
			yylex.(*Parser).positions.AddPosition(yylex.(*Parser).rootNode, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
		}
	case 2:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:244
		{
			if yyDollar[2].node != nil {
				yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)
			}
		}
	case 3:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:249
		{
			yyVAL.list = []node.Node{}
		}
	case 4:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:254
		{
			namePart := name.NewNamePart(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(namePart, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.list = []node.Node{namePart}
			yylex.(*Parser).comments.AddComments(namePart, yyDollar[1].token.Comments())
		}
	case 5:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:261
		{
			namePart := name.NewNamePart(yyDollar[3].token.Value)
			yylex.(*Parser).positions.AddPosition(namePart, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.list = append(yyDollar[1].list, namePart)
			yylex.(*Parser).comments.AddComments(namePart, yyDollar[3].token.Comments())
		}
	case 6:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:271
		{
			// error
			yyVAL.node = nil
		}
	case 7:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:276
		{
			yyVAL.node = yyDollar[1].node
		}
	case 8:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:278
		{
			yyVAL.node = yyDollar[1].node
		}
	case 9:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:280
		{
			yyVAL.node = yyDollar[1].node
		}
	case 10:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:282
		{
			yyVAL.node = stmt.NewHaltCompiler()
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 11:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:288
		{
			name := name.NewName(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node = stmt.NewNamespace(name, nil)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[2].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 12:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:298
		{
			name := name.NewName(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node = stmt.NewNamespace(name, yyDollar[4].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[5].token))

			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[2].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 13:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:308
		{
			yyVAL.node = stmt.NewNamespace(nil, yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 14:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:314
		{
			yyVAL.node = stmt.NewUseList(nil, yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 15:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:320
		{
			useType := node.NewIdentifier(yyDollar[2].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[2].token.Comments())

			yyVAL.node = stmt.NewUseList(useType, yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 16:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:330
		{
			useType := node.NewIdentifier(yyDollar[2].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[2].token.Comments())

			yyVAL.node = stmt.NewUseList(useType, yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 17:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:340
		{
			yyVAL.node = yyDollar[1].node
		}
	case 18:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:345
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 19:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:347
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 20:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:352
		{
			name := name.NewName(yyDollar[1].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yyVAL.node = stmt.NewUse(nil, name, nil)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))

			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))
		}
	case 21:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:362
		{
			name := name.NewName(yyDollar[1].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			alias := node.NewIdentifier(yyDollar[3].token.Value)
			yylex.(*Parser).positions.AddPosition(alias, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node = stmt.NewUse(nil, name, alias)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[1].list, yyDollar[3].token))

			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))
			yylex.(*Parser).comments.AddComments(alias, yyDollar[3].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))
		}
	case 22:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:375
		{
			name := name.NewName(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node = stmt.NewUse(nil, name, nil)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))

			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[2].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).listGetFirstNodeComments(yyDollar[2].list))
		}
	case 23:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:385
		{
			name := name.NewName(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			alias := node.NewIdentifier(yyDollar[4].token.Value)
			yylex.(*Parser).positions.AddPosition(alias, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yyVAL.node = stmt.NewUse(nil, name, alias)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[2].list, yyDollar[4].token))

			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[2].list))
			yylex.(*Parser).comments.AddComments(alias, yyDollar[4].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).listGetFirstNodeComments(yyDollar[2].list))
		}
	case 24:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:401
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 25:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:403
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 26:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:408
		{
			name := name.NewName(yyDollar[1].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yyVAL.node = stmt.NewUse(nil, name, nil)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))

			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))
		}
	case 27:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:418
		{
			name := name.NewName(yyDollar[1].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			alias := node.NewIdentifier(yyDollar[3].token.Value)
			yylex.(*Parser).positions.AddPosition(alias, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node = stmt.NewUse(nil, name, alias)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[1].list, yyDollar[3].token))

			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))
			yylex.(*Parser).comments.AddComments(alias, yyDollar[3].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))
		}
	case 28:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:431
		{
			name := name.NewName(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node = stmt.NewUse(nil, name, nil)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))

			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[2].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).listGetFirstNodeComments(yyDollar[2].list))
		}
	case 29:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:441
		{
			name := name.NewName(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			alias := node.NewIdentifier(yyDollar[4].token.Value)
			yylex.(*Parser).positions.AddPosition(alias, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yyVAL.node = stmt.NewUse(nil, name, alias)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[2].list, yyDollar[4].token))

			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[2].list))
			yylex.(*Parser).comments.AddComments(alias, yyDollar[4].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).listGetFirstNodeComments(yyDollar[2].list))
		}
	case 30:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:457
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 31:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:459
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 32:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:464
		{
			name := name.NewName(yyDollar[1].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yyVAL.node = stmt.NewUse(nil, name, nil)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))

			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))
		}
	case 33:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:474
		{
			name := name.NewName(yyDollar[1].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			alias := node.NewIdentifier(yyDollar[3].token.Value)
			yylex.(*Parser).positions.AddPosition(alias, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node = stmt.NewUse(nil, name, alias)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[1].list, yyDollar[3].token))

			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))
			yylex.(*Parser).comments.AddComments(alias, yyDollar[3].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))
		}
	case 34:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:487
		{
			name := name.NewName(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			yyVAL.node = stmt.NewUse(nil, name, nil)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))

			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[2].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).listGetFirstNodeComments(yyDollar[2].list))
		}
	case 35:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:497
		{
			name := name.NewName(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[2].list))
			alias := node.NewIdentifier(yyDollar[4].token.Value)
			yylex.(*Parser).positions.AddPosition(alias, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yyVAL.node = stmt.NewUse(nil, name, alias)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[2].list, yyDollar[4].token))

			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[2].list))
			yylex.(*Parser).comments.AddComments(alias, yyDollar[4].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).listGetFirstNodeComments(yyDollar[2].list))
		}
	case 36:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:513
		{
			name := node.NewIdentifier(yyDollar[3].token.Value)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(name, yyDollar[3].token.Comments())

			constant := stmt.NewConstant(name, yyDollar[5].node, "")
			yylex.(*Parser).positions.AddPosition(constant, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[5].node))
			yylex.(*Parser).comments.AddComments(constant, yyDollar[3].token.Comments())

			constList := yyDollar[1].node.(*stmt.ConstList)
			constList.Consts = append(constList.Consts, constant)

			yyVAL.node = yyDollar[1].node
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeNodeListPosition(yyDollar[1].node, constList.Consts))
		}
	case 37:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:529
		{
			name := node.NewIdentifier(yyDollar[2].token.Value)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(name, yyDollar[2].token.Comments())

			constant := stmt.NewConstant(name, yyDollar[4].node, "")
			yylex.(*Parser).positions.AddPosition(constant, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[2].token, yyDollar[4].node))
			yylex.(*Parser).comments.AddComments(constant, yyDollar[2].token.Comments())

			constList := []node.Node{constant}

			yyVAL.node = stmt.NewConstList(constList)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, constList))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 38:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:548
		{
			if yyDollar[2].node != nil {
				yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)
			}
		}
	case 39:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:554
		{
			yyVAL.list = []node.Node{}
		}
	case 40:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:560
		{
			// error
			yyVAL.node = nil
		}
	case 41:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:565
		{
			yyVAL.node = yyDollar[1].node
		}
	case 42:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:567
		{
			yyVAL.node = yyDollar[1].node
		}
	case 43:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:569
		{
			yyVAL.node = yyDollar[1].node
		}
	case 44:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:571
		{
			yyVAL.node = stmt.NewHaltCompiler()
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 45:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:581
		{
			yyVAL.node = yyDollar[1].node
		}
	case 46:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:583
		{
			label := node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(label, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node = stmt.NewLabel(label)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))

			yylex.(*Parser).comments.AddComments(label, yyDollar[1].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 47:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:596
		{
			yyVAL.node = stmt.NewStmtList(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 48:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:602
		{
			yyVAL.node = stmt.NewIf(yyDollar[2].node, yyDollar[3].node, yyDollar[4].list, yyDollar[5].node)

			if yyDollar[5].node != nil {
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[5].node))
			} else if len(yyDollar[4].list) > 0 {
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[4].list))
			} else {
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))
			}

			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 49:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line php5/php5.y:616
		{
			stmts := stmt.NewStmtList(yyDollar[4].list)
			yylex.(*Parser).positions.AddPosition(stmts, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[4].list))

			yyVAL.node = stmt.NewAltIf(yyDollar[2].node, stmts, yyDollar[5].list, yyDollar[6].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[8].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 50:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:625
		{
			if yyDollar[3].altSyntaxNode.isAlt {
				yyVAL.node = stmt.NewAltWhile(yyDollar[2].node, yyDollar[3].altSyntaxNode.node)
			} else {
				yyVAL.node = stmt.NewWhile(yyDollar[2].node, yyDollar[3].altSyntaxNode.node)
			}
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].altSyntaxNode.node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 51:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:635
		{
			yyVAL.node = stmt.NewDo(yyDollar[2].node, yyDollar[4].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[5].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 52:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line php5/php5.y:641
		{
			if yyDollar[9].altSyntaxNode.isAlt {
				yyVAL.node = stmt.NewAltFor(yyDollar[3].list, yyDollar[5].list, yyDollar[7].list, yyDollar[9].altSyntaxNode.node)
			} else {
				yyVAL.node = stmt.NewFor(yyDollar[3].list, yyDollar[5].list, yyDollar[7].list, yyDollar[9].altSyntaxNode.node)
			}
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[9].altSyntaxNode.node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 53:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:651
		{
			if yyDollar[3].nodesWithEndToken.endToken.Value == ";" {
				yyVAL.node = stmt.NewAltSwitch(yyDollar[2].node, yyDollar[3].nodesWithEndToken.nodes)
			} else {
				yyVAL.node = stmt.NewSwitch(yyDollar[2].node, yyDollar[3].nodesWithEndToken.nodes)
			}
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].nodesWithEndToken.endToken))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 54:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:661
		{
			yyVAL.node = stmt.NewBreak(nil)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 55:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:667
		{
			yyVAL.node = stmt.NewBreak(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 56:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:673
		{
			yyVAL.node = stmt.NewContinue(nil)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 57:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:679
		{
			yyVAL.node = stmt.NewContinue(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 58:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:685
		{
			yyVAL.node = stmt.NewReturn(nil)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 59:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:691
		{
			yyVAL.node = stmt.NewReturn(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 60:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:697
		{
			yyVAL.node = stmt.NewReturn(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 61:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:703
		{
			yyVAL.node = stmt.NewExpression(yyDollar[1].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 62:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:709
		{
			yyVAL.node = stmt.NewGlobal(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 63:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:715
		{
			yyVAL.node = stmt.NewStatic(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 64:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:721
		{
			yyVAL.node = stmt.NewEcho(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 65:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:727
		{
			yyVAL.node = stmt.NewInlineHtml(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 66:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:733
		{
			yyVAL.node = stmt.NewExpression(yyDollar[1].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 67:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:739
		{
			yyVAL.node = stmt.NewUnset(yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[5].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 68:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line php5/php5.y:745
		{
			if yyDollar[6].foreachVariable.node == nil {
				if yyDollar[8].altSyntaxNode.isAlt {
					yyVAL.node = stmt.NewAltForeach(yyDollar[3].node, nil, yyDollar[5].foreachVariable.node, yyDollar[8].altSyntaxNode.node, yyDollar[5].foreachVariable.byRef)
				} else {
					yyVAL.node = stmt.NewForeach(yyDollar[3].node, nil, yyDollar[5].foreachVariable.node, yyDollar[8].altSyntaxNode.node, yyDollar[5].foreachVariable.byRef)
				}
			} else {
				if yyDollar[8].altSyntaxNode.isAlt {
					yyVAL.node = stmt.NewAltForeach(yyDollar[3].node, yyDollar[5].foreachVariable.node, yyDollar[6].foreachVariable.node, yyDollar[8].altSyntaxNode.node, yyDollar[6].foreachVariable.byRef)
				} else {
					yyVAL.node = stmt.NewForeach(yyDollar[3].node, yyDollar[5].foreachVariable.node, yyDollar[6].foreachVariable.node, yyDollar[8].altSyntaxNode.node, yyDollar[6].foreachVariable.byRef)
				}
			}
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[8].altSyntaxNode.node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 69:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line php5/php5.y:763
		{
			if yyDollar[6].foreachVariable.node == nil {
				if yyDollar[8].altSyntaxNode.isAlt {
					yyVAL.node = stmt.NewAltForeach(yyDollar[3].node, nil, yyDollar[5].foreachVariable.node, yyDollar[8].altSyntaxNode.node, yyDollar[5].foreachVariable.byRef)
				} else {
					yyVAL.node = stmt.NewForeach(yyDollar[3].node, nil, yyDollar[5].foreachVariable.node, yyDollar[8].altSyntaxNode.node, yyDollar[5].foreachVariable.byRef)
				}
			} else {
				if yyDollar[8].altSyntaxNode.isAlt {
					yyVAL.node = stmt.NewAltForeach(yyDollar[3].node, yyDollar[5].foreachVariable.node, yyDollar[6].foreachVariable.node, yyDollar[8].altSyntaxNode.node, yyDollar[6].foreachVariable.byRef)
				} else {
					yyVAL.node = stmt.NewForeach(yyDollar[3].node, yyDollar[5].foreachVariable.node, yyDollar[6].foreachVariable.node, yyDollar[8].altSyntaxNode.node, yyDollar[6].foreachVariable.byRef)
				}
			}
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[8].altSyntaxNode.node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 70:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:781
		{
			yyVAL.node = stmt.NewDeclare(yyDollar[3].list, yyDollar[5].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[5].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 71:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:787
		{
			yyVAL.node = stmt.NewNop()
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 72:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php5/php5.y:793
		{
			yyVAL.node = stmt.NewTry(yyDollar[3].list, yyDollar[5].list, yyDollar[6].node)

			if yyDollar[6].node == nil {
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[5].list))
			} else {
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[6].node))
			}

			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 73:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:805
		{
			yyVAL.node = stmt.NewThrow(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 74:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:811
		{
			label := node.NewIdentifier(yyDollar[2].token.Value)
			yylex.(*Parser).positions.AddPosition(label, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node = stmt.NewGoto(label)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			yylex.(*Parser).comments.AddComments(label, yyDollar[2].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 75:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:824
		{
			yyVAL.list = []node.Node{}
		}
	case 76:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line php5/php5.y:826
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[4].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(identifier, yyDollar[4].token.Comments())

			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(variable, yyDollar[4].token.Comments())

			catch := stmt.NewCatch([]node.Node{yyDollar[3].node}, variable, yyDollar[7].list)
			yylex.(*Parser).positions.AddPosition(catch, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[8].token))
			yylex.(*Parser).comments.AddComments(catch, yyDollar[1].token.Comments())

			yyVAL.list = append([]node.Node{catch}, yyDollar[9].list...)
		}
	case 77:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:844
		{
			yyVAL.node = nil
		}
	case 78:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:846
		{
			yyVAL.node = stmt.NewFinally(yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 79:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:855
		{
			yyVAL.list = yyDollar[1].list
		}
	case 80:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:857
		{
			yyVAL.list = []node.Node{}
		}
	case 81:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:862
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 82:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:864
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)
		}
	case 83:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line php5/php5.y:869
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[4].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(identifier, yyDollar[4].token.Comments())

			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(variable, yyDollar[4].token.Comments())

			yyVAL.node = stmt.NewCatch([]node.Node{yyDollar[3].node}, variable, yyDollar[7].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[8].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 84:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:886
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 85:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:888
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 86:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:893
		{
			yyVAL.node = yyDollar[1].node
		}
	case 87:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:898
		{
			yyVAL.node = yyDollar[1].node
		}
	case 88:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:903
		{
			yyVAL.node = yyDollar[1].node
		}
	case 89:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:908
		{
			yyVAL.boolWithToken = boolWithToken{false, nil}
		}
	case 90:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:910
		{
			yyVAL.boolWithToken = boolWithToken{true, &yyDollar[1].token}
		}
	case 91:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:915
		{
			yyVAL.boolWithToken = boolWithToken{false, nil}
		}
	case 92:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:917
		{
			yyVAL.boolWithToken = boolWithToken{true, &yyDollar[1].token}
		}
	case 93:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line php5/php5.y:922
		{
			name := node.NewIdentifier(yyDollar[3].token.Value)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(name, yyDollar[3].token.Comments())

			yyVAL.node = stmt.NewFunction(name, yyDollar[2].boolWithToken.value, yyDollar[5].list, nil, yyDollar[8].list, "")
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[9].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 94:
		yyDollar = yyS[yypt-7 : yypt+1]
		//line php5/php5.y:935
		{
			switch n := yyDollar[1].node.(type) {
			case *stmt.Class:
				name := node.NewIdentifier(yyDollar[2].token.Value)
				yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
				n.ClassName = name
				n.Stmts = yyDollar[6].list
				n.Extends = yyDollar[3].node
				n.Implements = yyDollar[4].list

			case *stmt.Trait:
				// TODO: is it possible that trait extend or implement
				name := node.NewIdentifier(yyDollar[2].token.Value)
				yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
				n.TraitName = name
				n.Stmts = yyDollar[6].list
			}

			yyVAL.node = yyDollar[1].node
		}
	case 95:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php5/php5.y:956
		{
			name := node.NewIdentifier(yyDollar[2].token.Value)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(name, yyDollar[2].token.Comments())

			yyVAL.node = stmt.NewInterface(name, yyDollar[3].list, yyDollar[5].list, "")
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[6].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 96:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:970
		{
			yyVAL.node = stmt.NewClass(nil, nil, nil, nil, nil, nil, "")
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 97:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:976
		{
			classModifier := node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(classModifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(classModifier, yyDollar[1].token.Comments())

			yyVAL.node = stmt.NewClass(nil, []node.Node{classModifier}, nil, nil, nil, nil, "")
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 98:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:986
		{
			yyVAL.node = stmt.NewTrait(nil, nil, "")
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 99:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:992
		{
			classModifier := node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(classModifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(classModifier, yyDollar[1].token.Comments())

			yyVAL.node = stmt.NewClass(nil, []node.Node{classModifier}, nil, nil, nil, nil, "")
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 100:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1005
		{
			yyVAL.node = nil
		}
	case 101:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1007
		{
			yyVAL.node = yyDollar[2].node
		}
	case 102:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1012
		{
			yyVAL.token = yyDollar[1].token
		}
	case 103:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1017
		{
			yyVAL.list = nil
		}
	case 104:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1019
		{
			yyVAL.list = yyDollar[2].list
		}
	case 105:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1024
		{
			yyVAL.list = nil
		}
	case 106:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1026
		{
			yyVAL.list = yyDollar[2].list
		}
	case 107:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1031
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 108:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1033
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 109:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1038
		{
			yyVAL.foreachVariable = foreachVariable{nil, false}
		}
	case 110:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1040
		{
			yyVAL.foreachVariable = yyDollar[2].foreachVariable
		}
	case 111:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1045
		{
			yyVAL.foreachVariable = foreachVariable{yyDollar[1].node, false}
		}
	case 112:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1047
		{
			yyVAL.foreachVariable = foreachVariable{yyDollar[2].node, true}
		}
	case 113:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1049
		{
			list := expr.NewList(yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(list, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yyVAL.foreachVariable = foreachVariable{list, false}
			yylex.(*Parser).comments.AddComments(list, yyDollar[1].token.Comments())
		}
	case 114:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1059
		{
			yyVAL.altSyntaxNode = altSyntaxNode{yyDollar[1].node, false}
		}
	case 115:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1061
		{
			yyVAL.altSyntaxNode = altSyntaxNode{stmt.NewStmtList(yyDollar[2].list), true}
			yylex.(*Parser).positions.AddPosition(yyVAL.altSyntaxNode.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
		}
	case 116:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1070
		{
			yyVAL.altSyntaxNode = altSyntaxNode{yyDollar[1].node, false}
		}
	case 117:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1072
		{
			yyVAL.altSyntaxNode = altSyntaxNode{stmt.NewStmtList(yyDollar[2].list), true}
			yylex.(*Parser).positions.AddPosition(yyVAL.altSyntaxNode.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
		}
	case 118:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1081
		{
			yyVAL.node = yyDollar[1].node
		}
	case 119:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1083
		{
			yyVAL.node = stmt.NewStmtList(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 120:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1093
		{
			name := node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(name, yyDollar[1].token.Comments())

			constant := stmt.NewConstant(name, yyDollar[3].node, "")
			yylex.(*Parser).positions.AddPosition(constant, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(constant, yyDollar[1].token.Comments())

			yyVAL.list = []node.Node{constant}
		}
	case 121:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:1105
		{
			name := node.NewIdentifier(yyDollar[3].token.Value)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(name, yyDollar[3].token.Comments())

			constant := stmt.NewConstant(name, yyDollar[5].node, "")
			yylex.(*Parser).positions.AddPosition(constant, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[5].node))
			yylex.(*Parser).comments.AddComments(constant, yyDollar[3].token.Comments())

			yyVAL.list = append(yyDollar[1].list, constant)
		}
	case 122:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1121
		{
			yyVAL.nodesWithEndToken = &nodesWithEndToken{yyDollar[2].list, yyDollar[3].token}
		}
	case 123:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1123
		{
			yyVAL.nodesWithEndToken = &nodesWithEndToken{yyDollar[3].list, yyDollar[4].token}
		}
	case 124:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1125
		{
			yyVAL.nodesWithEndToken = &nodesWithEndToken{yyDollar[2].list, yyDollar[4].token}
		}
	case 125:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:1127
		{
			yyVAL.nodesWithEndToken = &nodesWithEndToken{yyDollar[3].list, yyDollar[5].token}
		}
	case 126:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1133
		{
			yyVAL.list = []node.Node{}
		}
	case 127:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:1135
		{
			_case := stmt.NewCase(yyDollar[3].node, yyDollar[5].list)
			yylex.(*Parser).positions.AddPosition(_case, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[2].token, yyDollar[5].list))
			yyVAL.list = append(yyDollar[1].list, _case)
			yylex.(*Parser).comments.AddComments(_case, yyDollar[2].token.Comments())
		}
	case 128:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1142
		{
			_default := stmt.NewDefault(yyDollar[4].list)
			yylex.(*Parser).positions.AddPosition(_default, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[2].token, yyDollar[4].list))
			yyVAL.list = append(yyDollar[1].list, _default)
			yylex.(*Parser).comments.AddComments(_default, yyDollar[2].token.Comments())
		}
	case 131:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1159
		{
			yyVAL.altSyntaxNode = altSyntaxNode{yyDollar[1].node, false}
		}
	case 132:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1161
		{
			yyVAL.altSyntaxNode = altSyntaxNode{stmt.NewStmtList(yyDollar[2].list), true}
			yylex.(*Parser).positions.AddPosition(yyVAL.altSyntaxNode.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
		}
	case 133:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1171
		{
			yyVAL.list = nil
		}
	case 134:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1173
		{
			_elseIf := stmt.NewElseIf(yyDollar[3].node, yyDollar[4].node)
			yylex.(*Parser).positions.AddPosition(_elseIf, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[2].token, yyDollar[4].node))
			yylex.(*Parser).comments.AddComments(_elseIf, yyDollar[2].token.Comments())

			yyVAL.list = append(yyDollar[1].list, _elseIf)
		}
	case 135:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1185
		{
			yyVAL.list = nil
		}
	case 136:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:1187
		{
			stmts := stmt.NewStmtList(yyDollar[5].list)
			yylex.(*Parser).positions.AddPosition(stmts, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[5].list))

			_elseIf := stmt.NewAltElseIf(yyDollar[3].node, stmts)
			yylex.(*Parser).positions.AddPosition(_elseIf, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[2].token, yyDollar[5].list))
			yylex.(*Parser).comments.AddComments(_elseIf, yyDollar[2].token.Comments())

			yyVAL.list = append(yyDollar[1].list, _elseIf)
		}
	case 137:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1202
		{
			yyVAL.node = nil
		}
	case 138:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1204
		{
			yyVAL.node = stmt.NewElse(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 139:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1214
		{
			yyVAL.node = nil
		}
	case 140:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1216
		{
			stmts := stmt.NewStmtList(yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(stmts, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[3].list))

			yyVAL.node = stmt.NewAltElse(stmts)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[3].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 141:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1229
		{
			yyVAL.list = yyDollar[1].list
		}
	case 142:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1231
		{
			yyVAL.list = nil
		}
	case 143:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1236
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 144:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1238
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 145:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1243
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[4].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[4].token.Comments())

			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[4].token.Comments())

			yyVAL.node = node.NewParameter(yyDollar[1].node, variable, nil, yyDollar[2].boolWithToken.value, yyDollar[3].boolWithToken.value)

			if yyDollar[1].node != nil {
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))
				yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
			} else if yyDollar[2].boolWithToken.value == true {
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(*yyDollar[2].boolWithToken.token, yyDollar[4].token))
				yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[2].boolWithToken.token.Comments())
			} else if yyDollar[3].boolWithToken.value == true {
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(*yyDollar[3].boolWithToken.token, yyDollar[4].token))
				yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[3].boolWithToken.token.Comments())
			} else {
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
				yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[4].token.Comments())
			}
		}
	case 146:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php5/php5.y:1269
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[4].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(identifier, yyDollar[4].token.Comments())

			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(variable, yyDollar[4].token.Comments())

			yyVAL.node = node.NewParameter(yyDollar[1].node, variable, yyDollar[6].node, yyDollar[2].boolWithToken.value, yyDollar[3].boolWithToken.value)

			if yyDollar[1].node != nil {
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[6].node))
				yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
			} else if yyDollar[2].boolWithToken.value == true {
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(*yyDollar[2].boolWithToken.token, yyDollar[6].node))
				yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[2].boolWithToken.token.Comments())
			} else if yyDollar[3].boolWithToken.value == true {
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(*yyDollar[3].boolWithToken.token, yyDollar[6].node))
				yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[3].boolWithToken.token.Comments())
			} else {
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[4].token, yyDollar[6].node))
				yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[4].token.Comments())
			}
		}
	case 147:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1299
		{
			yyVAL.node = nil
		}
	case 148:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1301
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 149:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1307
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 150:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1313
		{
			yyVAL.node = yyDollar[1].node
		}
	case 151:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1319
		{
			yyVAL.nodesWithEndToken = &nodesWithEndToken{[]node.Node{}, yyDollar[2].token}
		}
	case 152:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1321
		{
			yyVAL.nodesWithEndToken = &nodesWithEndToken{yyDollar[2].list, yyDollar[3].token}
		}
	case 153:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1323
		{
			arg := node.NewArgument(yyDollar[2].node, false, false)
			yylex.(*Parser).positions.AddPosition(arg, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(arg, yylex.(*Parser).comments[yyDollar[2].node])

			yyVAL.nodesWithEndToken = &nodesWithEndToken{[]node.Node{arg}, yyDollar[3].token}
		}
	case 154:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1335
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 155:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1337
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 156:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1342
		{
			yyVAL.node = node.NewArgument(yyDollar[1].node, false, false)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 157:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1348
		{
			yyVAL.node = node.NewArgument(yyDollar[1].node, false, false)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 158:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1354
		{
			yyVAL.node = node.NewArgument(yyDollar[2].node, false, true)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 159:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1360
		{
			yyVAL.node = node.NewArgument(yyDollar[2].node, true, false)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 160:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1369
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 161:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1371
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 162:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1377
		{
			name := node.NewIdentifier(strings.TrimLeft(yyDollar[1].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node = expr.NewVariable(name)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			yylex.(*Parser).comments.AddComments(name, yyDollar[1].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 163:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1387
		{
			yyVAL.node = expr.NewVariable(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 164:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1393
		{
			yyVAL.node = expr.NewVariable(yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 165:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1403
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[3].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))

			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))

			staticVar := stmt.NewStaticVar(variable, nil)
			yylex.(*Parser).positions.AddPosition(staticVar, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))

			yyVAL.list = append(yyDollar[1].list, staticVar)

			yylex.(*Parser).comments.AddComments(identifier, yyDollar[3].token.Comments())
			yylex.(*Parser).comments.AddComments(variable, yyDollar[3].token.Comments())
			yylex.(*Parser).comments.AddComments(staticVar, yyDollar[3].token.Comments())
		}
	case 166:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:1420
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[3].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))

			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))

			staticVar := stmt.NewStaticVar(variable, yyDollar[5].node)
			yylex.(*Parser).positions.AddPosition(staticVar, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[5].node))

			yyVAL.list = append(yyDollar[1].list, staticVar)

			yylex.(*Parser).comments.AddComments(identifier, yyDollar[3].token.Comments())
			yylex.(*Parser).comments.AddComments(variable, yyDollar[3].token.Comments())
			yylex.(*Parser).comments.AddComments(staticVar, yyDollar[3].token.Comments())
		}
	case 167:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1437
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[1].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			staticVar := stmt.NewStaticVar(variable, nil)
			yylex.(*Parser).positions.AddPosition(staticVar, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			yyVAL.list = []node.Node{staticVar}

			yylex.(*Parser).comments.AddComments(identifier, yyDollar[1].token.Comments())
			yylex.(*Parser).comments.AddComments(variable, yyDollar[1].token.Comments())
			yylex.(*Parser).comments.AddComments(staticVar, yyDollar[1].token.Comments())
		}
	case 168:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1454
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[1].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			staticVar := stmt.NewStaticVar(variable, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(staticVar, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))

			yyVAL.list = []node.Node{staticVar}

			yylex.(*Parser).comments.AddComments(identifier, yyDollar[1].token.Comments())
			yylex.(*Parser).comments.AddComments(variable, yyDollar[1].token.Comments())
			yylex.(*Parser).comments.AddComments(staticVar, yyDollar[1].token.Comments())
		}
	case 169:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1476
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)
		}
	case 170:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1478
		{
			yyVAL.list = []node.Node{}
		}
	case 171:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1484
		{
			yyVAL.node = stmt.NewPropertyList(yyDollar[1].list, yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[1].list, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))
		}
	case 172:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1490
		{
			yyVAL.node = yyDollar[1].node
		}
	case 173:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1492
		{
			yyVAL.node = yyDollar[1].node
		}
	case 174:
		yyDollar = yyS[yypt-8 : yypt+1]
		//line php5/php5.y:1494
		{
			name := node.NewIdentifier(yyDollar[4].token.Value)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(name, yyDollar[4].token.Comments())

			yyVAL.node = stmt.NewClassMethod(name, yyDollar[1].list, yyDollar[3].boolWithToken.value, yyDollar[6].list, nil, yyDollar[8].nodesWithEndToken.nodes, "")
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewOptionalListTokensPosition(yyDollar[1].list, yyDollar[2].token, yyDollar[8].nodesWithEndToken.endToken))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))
		}
	case 175:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1507
		{
			yyVAL.node = stmt.NewTraitUse(yyDollar[2].list, yyDollar[3].nodesWithEndToken.nodes)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].nodesWithEndToken.endToken))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 176:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1516
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 177:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1518
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 178:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1523
		{
			yyVAL.nodesWithEndToken = &nodesWithEndToken{nil, yyDollar[1].token}
		}
	case 179:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1525
		{
			yyVAL.nodesWithEndToken = &nodesWithEndToken{yyDollar[2].list, yyDollar[3].token}
		}
	case 180:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1530
		{
			yyVAL.list = nil
		}
	case 181:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1532
		{
			yyVAL.list = yyDollar[1].list
		}
	case 182:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1537
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 183:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1539
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)
		}
	case 184:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1544
		{
			yyVAL.node = yyDollar[1].node
		}
	case 185:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1546
		{
			yyVAL.node = yyDollar[1].node
		}
	case 186:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1551
		{
			yyVAL.node = stmt.NewTraitUsePrecedence(yyDollar[1].node, yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeNodeListPosition(yyDollar[1].node, yyDollar[3].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 187:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1560
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 188:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1562
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 189:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1567
		{
			name := node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(name, yyDollar[1].token.Comments())

			yyVAL.node = stmt.NewTraitMethodRef(nil, name)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 190:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1577
		{
			yyVAL.node = yyDollar[1].node
		}
	case 191:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1582
		{
			target := node.NewIdentifier(yyDollar[3].token.Value)
			yylex.(*Parser).positions.AddPosition(target, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(target, yyDollar[3].token.Comments())

			yyVAL.node = stmt.NewTraitMethodRef(yyDollar[1].node, target)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 192:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1595
		{
			alias := node.NewIdentifier(yyDollar[4].token.Value)
			yylex.(*Parser).positions.AddPosition(alias, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yyVAL.node = stmt.NewTraitUseAlias(yyDollar[1].node, yyDollar[3].node, alias)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))

			yylex.(*Parser).comments.AddComments(alias, yyDollar[4].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 193:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1605
		{
			yyVAL.node = stmt.NewTraitUseAlias(yyDollar[1].node, yyDollar[3].node, nil)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 194:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1614
		{
			yyVAL.node = nil
		}
	case 195:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1616
		{
			yyVAL.node = yyDollar[1].node
		}
	case 196:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1621
		{
			yyVAL.nodesWithEndToken = &nodesWithEndToken{nil, yyDollar[1].token}
		}
	case 197:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1623
		{
			yyVAL.nodesWithEndToken = &nodesWithEndToken{yyDollar[2].list, yyDollar[3].token}
		}
	case 198:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1628
		{
			yyVAL.list = yyDollar[1].list
		}
	case 199:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1630
		{
			modifier := node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(modifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(modifier, yyDollar[1].token.Comments())

			yyVAL.list = []node.Node{modifier}
		}
	case 200:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1641
		{
			yyVAL.list = nil
		}
	case 201:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1643
		{
			yyVAL.list = yyDollar[1].list
		}
	case 202:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1648
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 203:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1650
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)
		}
	case 204:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1655
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 205:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1661
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 206:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1667
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 207:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1673
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 208:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1679
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 209:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1685
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 210:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1694
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[3].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(identifier, yyDollar[3].token.Comments())

			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(variable, yyDollar[3].token.Comments())

			property := stmt.NewProperty(variable, nil, "")
			yylex.(*Parser).positions.AddPosition(property, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(property, yyDollar[3].token.Comments())

			yyVAL.list = append(yyDollar[1].list, property)
		}
	case 211:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:1710
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[3].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(identifier, yyDollar[3].token.Comments())

			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(variable, yyDollar[3].token.Comments())

			property := stmt.NewProperty(variable, yyDollar[5].node, "")
			yylex.(*Parser).positions.AddPosition(property, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[5].node))
			yylex.(*Parser).comments.AddComments(property, yyDollar[3].token.Comments())

			yyVAL.list = append(yyDollar[1].list, property)
		}
	case 212:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1726
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[1].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(identifier, yyDollar[1].token.Comments())

			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(variable, yyDollar[1].token.Comments())

			property := stmt.NewProperty(variable, nil, "")
			yylex.(*Parser).positions.AddPosition(property, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(property, yyDollar[1].token.Comments())

			yyVAL.list = []node.Node{property}
		}
	case 213:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1742
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[1].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(identifier, yyDollar[1].token.Comments())

			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(variable, yyDollar[1].token.Comments())

			property := stmt.NewProperty(variable, yyDollar[3].node, "")
			yylex.(*Parser).positions.AddPosition(property, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(property, yyDollar[1].token.Comments())

			yyVAL.list = []node.Node{property}
		}
	case 214:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:1761
		{
			name := node.NewIdentifier(yyDollar[3].token.Value)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(name, yyDollar[3].token.Comments())

			constant := stmt.NewConstant(name, yyDollar[5].node, "")
			yylex.(*Parser).positions.AddPosition(constant, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[5].node))
			yylex.(*Parser).comments.AddComments(constant, yyDollar[3].token.Comments())

			yyDollar[1].node.(*stmt.ClassConstList).Consts = append(yyDollar[1].node.(*stmt.ClassConstList).Consts, constant)
			yylex.(*Parser).positions.AddPosition(yyDollar[1].node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[5].node))

			yyVAL.node = yyDollar[1].node
		}
	case 215:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1776
		{
			name := node.NewIdentifier(yyDollar[2].token.Value)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(name, yyDollar[2].token.Comments())

			constant := stmt.NewConstant(name, yyDollar[4].node, "")
			yylex.(*Parser).positions.AddPosition(constant, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[2].token, yyDollar[4].node))
			yylex.(*Parser).comments.AddComments(constant, yyDollar[2].token.Comments())

			yyVAL.node = stmt.NewClassConstList(nil, []node.Node{constant})
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[4].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 216:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1793
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 217:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1795
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 218:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1801
		{
			yyVAL.list = nil
		}
	case 219:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1803
		{
			yyVAL.list = yyDollar[1].list
		}
	case 220:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1808
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 221:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1810
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 222:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1815
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].list...)
		}
	case 223:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1817
		{
			yyVAL.list = yyDollar[1].list
		}
	case 224:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1822
		{
			fetch := expr.NewArrayDimFetch(nil, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(fetch, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[3].node))

			yyVAL.list = append(yyDollar[1].list, fetch)
		}
	case 225:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1829
		{
			fetch := expr.NewArrayDimFetch(nil, yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(fetch, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[2].node))

			yyVAL.list = []node.Node{fetch}
		}
	case 226:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1839
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].list...)
		}
	case 227:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1841
		{
			yyVAL.list = yyDollar[1].list
		}
	case 228:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1843
		{
			yyVAL.list = yyDollar[1].list
		}
	case 229:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:1848
		{
			yyVAL.list = nil
		}
	case 230:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:1850
		{
			yyVAL.list = yyDollar[1].list
		}
	case 231:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1855
		{
			if yyDollar[3].nodesWithEndToken != nil {
				yyVAL.node = expr.NewNew(yyDollar[2].node, yyDollar[3].nodesWithEndToken.nodes)
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].nodesWithEndToken.endToken))
			} else {
				yyVAL.node = expr.NewNew(yyDollar[2].node, nil)
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			}

			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 232:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php5/php5.y:1870
		{
			list := expr.NewList(yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(list, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yyVAL.node = assign.NewAssign(list, yyDollar[6].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[6].node))

			yylex.(*Parser).comments.AddComments(list, yyDollar[1].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 233:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1880
		{
			yyVAL.node = assign.NewAssign(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 234:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:1886
		{
			yyVAL.node = assign.NewReference(yyDollar[1].node, yyDollar[4].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 235:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php5/php5.y:1892
		{
			_new := expr.NewNew(yyDollar[5].node, nil)
			yylex.(*Parser).positions.AddPosition(_new, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[4].token, yyDollar[5].node))

			if yyDollar[6].nodesWithEndToken != nil {
				_new = expr.NewNew(yyDollar[5].node, yyDollar[6].nodesWithEndToken.nodes)
				yylex.(*Parser).positions.AddPosition(_new, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[4].token, yyDollar[6].nodesWithEndToken.endToken))
			}
			yylex.(*Parser).comments.AddComments(_new, yylex.(*Parser).comments[yyDollar[1].node])

			yyVAL.node = assign.NewReference(yyDollar[1].node, _new)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, _new))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 236:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1907
		{
			yyVAL.node = expr.NewClone(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 237:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1913
		{
			yyVAL.node = assign.NewPlus(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 238:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1919
		{
			yyVAL.node = assign.NewMinus(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 239:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1925
		{
			yyVAL.node = assign.NewMul(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 240:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1931
		{
			yyVAL.node = assign.NewPow(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 241:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1937
		{
			yyVAL.node = assign.NewDiv(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 242:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1943
		{
			yyVAL.node = assign.NewConcat(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 243:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1949
		{
			yyVAL.node = assign.NewMod(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 244:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1955
		{
			yyVAL.node = assign.NewBitwiseAnd(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 245:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1961
		{
			yyVAL.node = assign.NewBitwiseOr(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 246:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1967
		{
			yyVAL.node = assign.NewBitwiseXor(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 247:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1973
		{
			yyVAL.node = assign.NewShiftLeft(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 248:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:1979
		{
			yyVAL.node = assign.NewShiftRight(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 249:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1985
		{
			yyVAL.node = expr.NewPostInc(yyDollar[1].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 250:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1991
		{
			yyVAL.node = expr.NewPreInc(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 251:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:1997
		{
			yyVAL.node = expr.NewPostDec(yyDollar[1].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 252:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2003
		{
			yyVAL.node = expr.NewPreDec(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 253:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2009
		{
			yyVAL.node = binary.NewBooleanOr(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 254:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2015
		{
			yyVAL.node = binary.NewBooleanAnd(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 255:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2021
		{
			yyVAL.node = binary.NewLogicalOr(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 256:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2027
		{
			yyVAL.node = binary.NewLogicalAnd(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 257:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2033
		{
			yyVAL.node = binary.NewLogicalXor(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 258:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2039
		{
			yyVAL.node = binary.NewBitwiseOr(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 259:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2045
		{
			yyVAL.node = binary.NewBitwiseAnd(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 260:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2051
		{
			yyVAL.node = binary.NewBitwiseXor(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 261:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2057
		{
			yyVAL.node = binary.NewConcat(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 262:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2063
		{
			yyVAL.node = binary.NewPlus(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 263:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2069
		{
			yyVAL.node = binary.NewMinus(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 264:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2075
		{
			yyVAL.node = binary.NewMul(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 265:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2081
		{
			yyVAL.node = binary.NewPow(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 266:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2087
		{
			yyVAL.node = binary.NewDiv(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 267:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2093
		{
			yyVAL.node = binary.NewMod(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 268:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2099
		{
			yyVAL.node = binary.NewShiftLeft(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 269:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2105
		{
			yyVAL.node = binary.NewShiftRight(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 270:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2111
		{
			yyVAL.node = expr.NewUnaryPlus(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 271:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2117
		{
			yyVAL.node = expr.NewUnaryMinus(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 272:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2123
		{
			yyVAL.node = expr.NewBooleanNot(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 273:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2129
		{
			yyVAL.node = expr.NewBitwiseNot(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 274:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2135
		{
			yyVAL.node = binary.NewIdentical(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 275:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2141
		{
			yyVAL.node = binary.NewNotIdentical(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 276:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2147
		{
			yyVAL.node = binary.NewEqual(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 277:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2153
		{
			yyVAL.node = binary.NewNotEqual(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 278:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2159
		{
			yyVAL.node = binary.NewSmaller(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 279:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2165
		{
			yyVAL.node = binary.NewSmallerOrEqual(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 280:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2171
		{
			yyVAL.node = binary.NewGreater(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 281:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2177
		{
			yyVAL.node = binary.NewGreaterOrEqual(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 282:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2183
		{
			yyVAL.node = expr.NewInstanceOf(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 283:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2189
		{
			yyVAL.node = yyDollar[1].node
		}
	case 284:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2191
		{
			yyVAL.node = yyDollar[1].node
		}
	case 285:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2193
		{
			yyVAL.node = yyDollar[2].node

			for _, n := range yyDollar[4].list {
				switch nn := n.(type) {
				case *expr.ArrayDimFetch:
					nn.Variable = yyVAL.node
					yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yylex.(*Parser).comments.AddComments(nn, yyDollar[1].token.Comments())
					yyVAL.node = nn

				case *expr.PropertyFetch:
					nn.Variable = yyVAL.node
					yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yylex.(*Parser).comments.AddComments(nn, yyDollar[1].token.Comments())
					yyVAL.node = nn

				case *expr.MethodCall:
					nn.Variable = yyVAL.node
					yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yylex.(*Parser).comments.AddComments(nn, yyDollar[1].token.Comments())
					yyVAL.node = nn
				}
			}
		}
	case 286:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:2219
		{
			yyVAL.node = expr.NewTernary(yyDollar[1].node, yyDollar[3].node, yyDollar[5].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[5].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 287:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2225
		{
			yyVAL.node = expr.NewTernary(yyDollar[1].node, nil, yyDollar[4].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 288:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2231
		{
			yyVAL.node = yyDollar[1].node
		}
	case 289:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2233
		{
			yyVAL.node = cast.NewInt(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 290:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2239
		{
			yyVAL.node = cast.NewDouble(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 291:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2245
		{
			yyVAL.node = cast.NewString(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 292:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2251
		{
			yyVAL.node = cast.NewArray(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 293:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2257
		{
			yyVAL.node = cast.NewObject(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 294:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2263
		{
			yyVAL.node = cast.NewBool(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 295:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2269
		{
			yyVAL.node = cast.NewUnset(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 296:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2275
		{
			if strings.EqualFold(yyDollar[1].token.Value, "die") {
				yyVAL.node = expr.NewDie(yyDollar[2].node)
			} else {
				yyVAL.node = expr.NewExit(yyDollar[2].node)
			}
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 297:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2285
		{
			yyVAL.node = expr.NewErrorSuppress(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 298:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2291
		{
			yyVAL.node = yyDollar[1].node
		}
	case 299:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2293
		{
			yyVAL.node = yyDollar[1].node
		}
	case 300:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2295
		{
			yyVAL.node = yyDollar[1].node
		}
	case 301:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2297
		{
			yyVAL.node = expr.NewShellExec(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 302:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2303
		{
			yyVAL.node = expr.NewPrint(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 303:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2309
		{
			yyVAL.node = expr.NewYield(nil, nil)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 304:
		yyDollar = yyS[yypt-9 : yypt+1]
		//line php5/php5.y:2315
		{
			yyVAL.node = expr.NewClosure(yyDollar[4].list, yyDollar[6].list, nil, yyDollar[8].list, false, yyDollar[2].boolWithToken.value, "")
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[9].token))

			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 305:
		yyDollar = yyS[yypt-10 : yypt+1]
		//line php5/php5.y:2322
		{
			yyVAL.node = expr.NewClosure(yyDollar[5].list, yyDollar[7].list, nil, yyDollar[9].list, true, yyDollar[3].boolWithToken.value, "")
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[10].token))

			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 306:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2332
		{
			yyVAL.node = expr.NewYield(nil, yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 307:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2338
		{
			yyVAL.node = expr.NewYield(nil, yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 308:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2344
		{
			yyVAL.node = expr.NewYield(yyDollar[2].node, yyDollar[4].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[4].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 309:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2350
		{
			yyVAL.node = expr.NewYield(yyDollar[2].node, yyDollar[4].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[4].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 310:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2359
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 311:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2365
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 312:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2371
		{
			str := scalar.NewString(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(str, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(str, yyDollar[1].token.Comments())

			yyVAL.node = expr.NewArrayDimFetch(str, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(str, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[str])
		}
	case 313:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2381
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 314:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2390
		{
			yyVAL.node = expr.NewArray(yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 315:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2396
		{
			yyVAL.node = expr.NewShortArray(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 316:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2405
		{
			yyVAL.token = yyDollar[1].token
		}
	case 317:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:2410
		{
			yyVAL.list = []node.Node{}
		}
	case 318:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2412
		{
			yyVAL.list = yyDollar[3].list
		}
	case 319:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2417
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[3].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(identifier, yyDollar[3].token.Comments())

			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(variable, yyDollar[3].token.Comments())

			use := expr.NewClosureUse(variable, false)
			yylex.(*Parser).positions.AddPosition(use, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(use, yyDollar[3].token.Comments())

			yyVAL.list = append(yyDollar[1].list, use)
		}
	case 320:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2433
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[4].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(identifier, yyDollar[4].token.Comments())

			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(variable, yyDollar[3].token.Comments())

			use := expr.NewClosureUse(variable, true)
			yylex.(*Parser).positions.AddPosition(use, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[3].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(use, yyDollar[3].token.Comments())

			yyVAL.list = append(yyDollar[1].list, use)
		}
	case 321:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2449
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[1].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(identifier, yyDollar[1].token.Comments())

			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(variable, yyDollar[1].token.Comments())

			use := expr.NewClosureUse(variable, false)
			yylex.(*Parser).positions.AddPosition(use, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(use, yyDollar[1].token.Comments())

			yyVAL.list = []node.Node{use}
		}
	case 322:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2465
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[2].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(identifier, yyDollar[2].token.Comments())

			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(variable, yyDollar[1].token.Comments())

			use := expr.NewClosureUse(variable, true)
			yylex.(*Parser).positions.AddPosition(use, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(use, yyDollar[1].token.Comments())

			yyVAL.list = []node.Node{use}
		}
	case 323:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2484
		{
			name := name.NewName(yyDollar[1].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))

			yyVAL.node = expr.NewFunctionCall(name, yyDollar[2].nodesWithEndToken.nodes)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(name, yyDollar[2].nodesWithEndToken.endToken))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[name])
		}
	case 324:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2494
		{
			funcName := name.NewRelative(yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(funcName, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[3].list))
			yylex.(*Parser).comments.AddComments(funcName, yyDollar[1].token.Comments())

			yyVAL.node = expr.NewFunctionCall(funcName, yyDollar[4].nodesWithEndToken.nodes)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(funcName, yyDollar[4].nodesWithEndToken.endToken))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[funcName])
		}
	case 325:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2504
		{
			funcName := name.NewFullyQualified(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(funcName, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))
			yylex.(*Parser).comments.AddComments(funcName, yyDollar[1].token.Comments())

			yyVAL.node = expr.NewFunctionCall(funcName, yyDollar[3].nodesWithEndToken.nodes)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(funcName, yyDollar[3].nodesWithEndToken.endToken))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[funcName])
		}
	case 326:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2514
		{
			yyVAL.node = expr.NewStaticCall(yyDollar[1].node, yyDollar[3].node, yyDollar[4].nodesWithEndToken.nodes)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].nodesWithEndToken.endToken))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 327:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2520
		{
			yyVAL.node = expr.NewStaticCall(yyDollar[1].node, yyDollar[3].node, yyDollar[4].nodesWithEndToken.nodes)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].nodesWithEndToken.endToken))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 328:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2526
		{
			yyVAL.node = expr.NewStaticCall(yyDollar[1].node, yyDollar[3].node, yyDollar[4].nodesWithEndToken.nodes)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].nodesWithEndToken.endToken))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 329:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2532
		{
			yyVAL.node = expr.NewStaticCall(yyDollar[1].node, yyDollar[3].node, yyDollar[4].nodesWithEndToken.nodes)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].nodesWithEndToken.endToken))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 330:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2538
		{
			yyVAL.node = expr.NewFunctionCall(yyDollar[1].node, yyDollar[2].nodesWithEndToken.nodes)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[2].nodesWithEndToken.endToken))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 331:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2547
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 332:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2553
		{
			yyVAL.node = name.NewName(yyDollar[1].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))
		}
	case 333:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2559
		{
			yyVAL.node = name.NewRelative(yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[3].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 334:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2565
		{
			yyVAL.node = name.NewFullyQualified(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 335:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2574
		{
			yyVAL.node = name.NewName(yyDollar[1].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))
		}
	case 336:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2580
		{
			yyVAL.node = name.NewRelative(yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[3].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 337:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2586
		{
			yyVAL.node = name.NewFullyQualified(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 338:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2595
		{
			yyVAL.node = yyDollar[1].node
		}
	case 339:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2597
		{
			yyVAL.node = yyDollar[1].node
		}
	case 340:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2602
		{
			yyVAL.node = yyDollar[1].node

			for _, n := range yyDollar[3].list {
				switch nn := n.(type) {
				case *expr.ArrayDimFetch:
					nn.Variable = yyVAL.node
					yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yylex.(*Parser).comments.AddComments(nn, yylex.(*Parser).comments[yyDollar[1].node])
					yyVAL.node = nn

				case *expr.PropertyFetch:
					nn.Variable = yyVAL.node
					yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yylex.(*Parser).comments.AddComments(nn, yylex.(*Parser).comments[yyDollar[1].node])
					yyVAL.node = nn
				}
			}

			for _, n := range yyDollar[4].list {
				switch nn := n.(type) {
				case *expr.ArrayDimFetch:
					nn.Variable = yyVAL.node
					yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yylex.(*Parser).comments.AddComments(nn, yylex.(*Parser).comments[yyDollar[1].node])
					yyVAL.node = nn

				case *expr.PropertyFetch:
					nn.Variable = yyVAL.node
					yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yylex.(*Parser).comments.AddComments(nn, yylex.(*Parser).comments[yyDollar[1].node])
					yyVAL.node = nn
				}
			}
		}
	case 341:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2638
		{
			yyVAL.node = yyDollar[1].node
		}
	case 342:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2644
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].list...)
		}
	case 343:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:2646
		{
			yyVAL.list = []node.Node{}
		}
	case 344:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2652
		{
			yyVAL.list = yyDollar[2].list
		}
	case 345:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:2657
		{
			yyVAL.node = nil
		}
	case 346:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2659
		{
			yyVAL.node = nil
		}
	case 347:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2661
		{
			yyVAL.node = yyDollar[1].node
		}
	case 348:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:2666
		{
			yyVAL.list = []node.Node{}
		}
	case 349:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2668
		{
			yyVAL.list = []node.Node{scalar.NewEncapsedStringPart(yyDollar[1].token.Value)}
		}
	case 350:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2670
		{
			yyVAL.list = yyDollar[1].list
		}
	case 351:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:2675
		{
			yyVAL.nodesWithEndToken = nil
		}
	case 352:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2677
		{
			yyVAL.nodesWithEndToken = yyDollar[1].nodesWithEndToken
		}
	case 353:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2682
		{
			yyVAL.node = scalar.NewLnumber(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 354:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2688
		{
			yyVAL.node = scalar.NewDnumber(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 355:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2694
		{
			yyVAL.node = scalar.NewString(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 356:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2700
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 357:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2706
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 358:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2712
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 359:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2718
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 360:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2724
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 361:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2730
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 362:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2736
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 363:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2742
		{
			encapsed := scalar.NewEncapsedStringPart(yyDollar[2].token.Value)
			yylex.(*Parser).positions.AddPosition(encapsed, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(encapsed, yyDollar[2].token.Comments())

			yyVAL.node = scalar.NewHeredoc(yyDollar[1].token.Value, []node.Node{encapsed})
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 364:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2752
		{
			yyVAL.node = scalar.NewHeredoc(yyDollar[1].token.Value, nil)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 365:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2761
		{
			target := node.NewIdentifier(yyDollar[3].token.Value)
			yylex.(*Parser).positions.AddPosition(target, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node = expr.NewClassConstFetch(yyDollar[1].node, target)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			yylex.(*Parser).comments.AddComments(target, yyDollar[3].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 366:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2774
		{
			yyVAL.node = yyDollar[1].node
		}
	case 367:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2779
		{
			yyVAL.node = yyDollar[1].node
		}
	case 368:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2781
		{
			yyVAL.node = yyDollar[1].node
		}
	case 369:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2783
		{
			name := name.NewName(yyDollar[1].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))

			yyVAL.node = expr.NewConstFetch(name)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodePosition(name))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[name])
		}
	case 370:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2793
		{
			name := name.NewRelative(yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[3].list))
			yylex.(*Parser).comments.AddComments(name, yyDollar[1].token.Comments())

			yyVAL.node = expr.NewConstFetch(name)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[3].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[name])
		}
	case 371:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2803
		{
			name := name.NewFullyQualified(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))
			yylex.(*Parser).comments.AddComments(name, yyDollar[1].token.Comments())

			yyVAL.node = expr.NewConstFetch(name)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[name])
		}
	case 372:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2813
		{
			yyVAL.node = expr.NewArray(yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 373:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2819
		{
			yyVAL.node = expr.NewShortArray(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 374:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2825
		{
			yyVAL.node = yyDollar[1].node
		}
	case 375:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2827
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 376:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:2833
		{
			yyVAL.node = yyDollar[1].node
		}
	case 377:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:2838
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 378:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2844
		{
			yyVAL.node = binary.NewPlus(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 379:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2850
		{
			yyVAL.node = binary.NewMinus(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 380:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2856
		{
			yyVAL.node = binary.NewMul(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 381:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2862
		{
			yyVAL.node = binary.NewPow(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 382:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2868
		{
			yyVAL.node = binary.NewDiv(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 383:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2874
		{
			yyVAL.node = binary.NewMod(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 384:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2880
		{
			yyVAL.node = expr.NewBooleanNot(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 385:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:2886
		{
			yyVAL.node = expr.NewBitwiseNot(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 386:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2892
		{
			yyVAL.node = binary.NewBitwiseOr(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 387:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2898
		{
			yyVAL.node = binary.NewBitwiseAnd(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 388:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2904
		{
			yyVAL.node = binary.NewBitwiseXor(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 389:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2910
		{
			yyVAL.node = binary.NewShiftLeft(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 390:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2916
		{
			yyVAL.node = binary.NewShiftRight(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 391:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2922
		{
			yyVAL.node = binary.NewConcat(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 392:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2928
		{
			yyVAL.node = binary.NewLogicalXor(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 393:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2934
		{
			yyVAL.node = binary.NewLogicalAnd(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 394:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2940
		{
			yyVAL.node = binary.NewLogicalOr(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 395:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2946
		{
			yyVAL.node = binary.NewBooleanAnd(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 396:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2952
		{
			yyVAL.node = binary.NewBooleanOr(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 397:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2958
		{
			yyVAL.node = binary.NewIdentical(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 398:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2964
		{
			yyVAL.node = binary.NewNotIdentical(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 399:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2970
		{
			yyVAL.node = binary.NewEqual(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 400:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2976
		{
			yyVAL.node = binary.NewNotEqual(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 401:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2982
		{
			yyVAL.node = binary.NewSmaller(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 402:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2988
		{
			yyVAL.node = binary.NewGreater(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 403:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:2994
		{
			yyVAL.node = binary.NewSmallerOrEqual(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 404:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3000
		{
			yyVAL.node = binary.NewGreaterOrEqual(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 405:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3006
		{
			yyVAL.node = expr.NewTernary(yyDollar[1].node, nil, yyDollar[4].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 406:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:3012
		{
			yyVAL.node = expr.NewTernary(yyDollar[1].node, yyDollar[3].node, yyDollar[5].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[5].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 407:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3018
		{
			yyVAL.node = expr.NewUnaryPlus(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 408:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3024
		{
			yyVAL.node = expr.NewUnaryMinus(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 409:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3030
		{
			yyVAL.node = yyDollar[2].node
		}
	case 410:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3035
		{
			yyVAL.node = yyDollar[1].node
		}
	case 411:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3037
		{
			name := name.NewName(yyDollar[1].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewNodeListPosition(yyDollar[1].list))
			yylex.(*Parser).comments.AddComments(name, yylex.(*Parser).listGetFirstNodeComments(yyDollar[1].list))

			yyVAL.node = expr.NewConstFetch(name)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodePosition(name))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[name])
		}
	case 412:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3047
		{
			name := name.NewRelative(yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[3].list))
			yylex.(*Parser).comments.AddComments(name, yyDollar[1].token.Comments())

			yyVAL.node = expr.NewConstFetch(name)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodePosition(name))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[name])
		}
	case 413:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3057
		{
			name := name.NewFullyQualified(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenNodeListPosition(yyDollar[1].token, yyDollar[2].list))
			yylex.(*Parser).comments.AddComments(name, yyDollar[1].token.Comments())

			yyVAL.node = expr.NewConstFetch(name)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodePosition(name))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[name])
		}
	case 414:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3070
		{
			name := node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node = expr.NewVariable(name)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			yylex.(*Parser).comments.AddComments(name, yyDollar[1].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 415:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3080
		{
			yyVAL.node = yyDollar[1].node
		}
	case 416:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3082
		{
			yyVAL.node = yyDollar[1].node
		}
	case 417:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3084
		{
			yyVAL.node = yyDollar[1].node
		}
	case 418:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3086
		{
			yyVAL.node = scalar.NewEncapsed(yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 419:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3092
		{
			yyVAL.node = scalar.NewHeredoc(yyDollar[1].token.Value, yyDollar[2].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 420:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3098
		{
			yyVAL.node = scalar.NewMagicConstant(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 421:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:3107
		{
			yyVAL.list = nil
		}
	case 422:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3109
		{
			yyVAL.list = yyDollar[1].list
		}
	case 425:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:3119
		{
			arrayItem := expr.NewArrayItem(yyDollar[3].node, yyDollar[5].node, false)
			yylex.(*Parser).positions.AddPosition(arrayItem, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[3].node, yyDollar[5].node))
			yylex.(*Parser).comments.AddComments(arrayItem, yylex.(*Parser).comments[yyDollar[3].node])

			yyVAL.list = append(yyDollar[1].list, arrayItem)
		}
	case 426:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3127
		{
			arrayItem := expr.NewArrayItem(nil, yyDollar[3].node, false)
			yylex.(*Parser).positions.AddPosition(arrayItem, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(arrayItem, yylex.(*Parser).comments[yyDollar[3].node])

			yyVAL.list = append(yyDollar[1].list, arrayItem)
		}
	case 427:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3135
		{
			arrayItem := expr.NewArrayItem(yyDollar[1].node, yyDollar[3].node, false)
			yylex.(*Parser).positions.AddPosition(arrayItem, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(arrayItem, yylex.(*Parser).comments[yyDollar[1].node])

			yyVAL.list = []node.Node{arrayItem}
		}
	case 428:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3143
		{
			arrayItem := expr.NewArrayItem(nil, yyDollar[1].node, false)
			yylex.(*Parser).positions.AddPosition(arrayItem, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))
			yylex.(*Parser).comments.AddComments(arrayItem, yylex.(*Parser).comments[yyDollar[1].node])

			yyVAL.list = []node.Node{arrayItem}
		}
	case 429:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3154
		{
			yyVAL.node = yyDollar[1].node
		}
	case 430:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3156
		{
			yyVAL.node = yyDollar[1].node
		}
	case 431:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3161
		{
			yyVAL.node = yyDollar[2].node
		}
	case 432:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3163
		{
			yyVAL.node = yyDollar[2].node
		}
	case 433:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3169
		{
			yyVAL.node = yyDollar[1].node
		}
	case 434:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3175
		{
			yyVAL.node = yyDollar[1].node
		}
	case 435:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3180
		{
			yyVAL.node = yyDollar[1].node
		}
	case 436:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:3185
		{
			yyVAL.node = yyDollar[1].node

			if yyDollar[4].list != nil {
				yyDollar[4].list[0].(*expr.MethodCall).Method = yyDollar[3].list[len(yyDollar[3].list)-1].(*expr.PropertyFetch).Property
				yyDollar[3].list = append(yyDollar[3].list[:len(yyDollar[3].list)-1], yyDollar[4].list...)
			}

			for _, n := range yyDollar[3].list {
				switch nn := n.(type) {
				case *expr.ArrayDimFetch:
					nn.Variable = yyVAL.node
					yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yylex.(*Parser).comments.AddComments(nn, yylex.(*Parser).comments[yyDollar[1].node])
					yyVAL.node = nn

				case *expr.PropertyFetch:
					nn.Variable = yyVAL.node
					yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yylex.(*Parser).comments.AddComments(nn, yylex.(*Parser).comments[yyDollar[1].node])
					yyVAL.node = nn

				case *expr.MethodCall:
					nn.Variable = yyVAL.node
					yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yylex.(*Parser).comments.AddComments(nn, yylex.(*Parser).comments[yyDollar[1].node])
					yyVAL.node = nn
				}
			}

			for _, n := range yyDollar[5].list {
				switch nn := n.(type) {
				case *expr.ArrayDimFetch:
					nn.Variable = yyVAL.node
					yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yylex.(*Parser).comments.AddComments(nn, yylex.(*Parser).comments[yyDollar[1].node])
					yyVAL.node = nn

				case *expr.PropertyFetch:
					nn.Variable = yyVAL.node
					yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yylex.(*Parser).comments.AddComments(nn, yylex.(*Parser).comments[yyDollar[1].node])
					yyVAL.node = nn

				case *expr.MethodCall:
					nn.Variable = yyVAL.node
					yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyVAL.node, nn))
					yylex.(*Parser).comments.AddComments(nn, yylex.(*Parser).comments[yyDollar[1].node])
					yyVAL.node = nn
				}
			}
		}
	case 437:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3238
		{
			yyVAL.node = yyDollar[1].node
		}
	case 438:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3243
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].list...)
		}
	case 439:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:3245
		{
			yyVAL.list = []node.Node{}
		}
	case 440:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3251
		{
			if yyDollar[3].list != nil {
				yyDollar[3].list[0].(*expr.MethodCall).Method = yyDollar[2].list[len(yyDollar[2].list)-1].(*expr.PropertyFetch).Property
				yyDollar[2].list = append(yyDollar[2].list[:len(yyDollar[2].list)-1], yyDollar[3].list...)
			}

			yyVAL.list = yyDollar[2].list
		}
	case 441:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3263
		{
			fetch := expr.NewArrayDimFetch(nil, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(fetch, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[3].node))

			yyVAL.list = append(yyDollar[1].list, fetch)
		}
	case 442:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3270
		{
			fetch := expr.NewArrayDimFetch(nil, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(fetch, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[3].node))

			yyVAL.list = []node.Node{yyDollar[1].node, fetch}
		}
	case 443:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3280
		{
			yyVAL.node = expr.NewMethodCall(nil, nil, yyDollar[1].nodesWithEndToken.nodes)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeListTokenPosition(yyDollar[1].nodesWithEndToken.nodes, yyDollar[1].nodesWithEndToken.endToken))
		}
	case 444:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3288
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 445:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3290
		{
			yyVAL.list = yyDollar[1].list
		}
	case 446:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:3292
		{
			yyVAL.list = nil
		}
	case 447:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3297
		{
			yyVAL.node = yyDollar[1].node
		}
	case 448:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3299
		{
			yyDollar[1].simpleIndirectReference.last.SetVarName(yyDollar[2].node)

			for _, n := range yyDollar[1].simpleIndirectReference.all {
				yylex.(*Parser).positions[n] = yylex.(*Parser).positionBuilder.NewNodesPosition(n, yyDollar[2].node)
			}

			yyVAL.node = yyDollar[1].simpleIndirectReference.all[0]
		}
	case 449:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3312
		{
			yyVAL.node = expr.NewStaticPropertyFetch(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 450:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3318
		{
			yyVAL.node = expr.NewStaticPropertyFetch(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 451:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3328
		{
			yyVAL.node = yyDollar[1].node
		}
	case 452:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3333
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 453:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3339
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 454:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3347
		{
			yyVAL.node = yyDollar[1].node
		}
	case 455:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3348
		{
			yyVAL.node = yyDollar[1].node
		}
	case 456:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3349
		{
			yyVAL.node = yyDollar[1].node
		}
	case 457:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3355
		{
			yyVAL.node = yyDollar[1].node
		}
	case 458:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3357
		{
			yyDollar[1].simpleIndirectReference.last.SetVarName(yyDollar[2].node)

			for _, n := range yyDollar[1].simpleIndirectReference.all {
				yylex.(*Parser).positions[n] = yylex.(*Parser).positionBuilder.NewNodesPosition(n, yyDollar[2].node)
			}

			yyVAL.node = yyDollar[1].simpleIndirectReference.all[0]
		}
	case 459:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3367
		{
			yyVAL.node = yyDollar[1].node
		}
	case 460:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3372
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 461:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3378
		{
			yyVAL.node = expr.NewArrayDimFetch(yyDollar[1].node, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 462:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3384
		{
			yyVAL.node = yyDollar[1].node
		}
	case 463:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3390
		{
			name := node.NewIdentifier(strings.TrimLeft(yyDollar[1].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node = expr.NewVariable(name)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			yylex.(*Parser).comments.AddComments(name, yyDollar[1].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 464:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3400
		{
			yyVAL.node = expr.NewVariable(yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 465:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:3409
		{
			yyVAL.node = nil
		}
	case 466:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3411
		{
			yyVAL.node = yyDollar[1].node
		}
	case 467:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3417
		{
			yyVAL.list = yyDollar[1].list
		}
	case 468:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3419
		{
			fetch := expr.NewPropertyFetch(nil, yyDollar[1].node)
			yylex.(*Parser).positions.AddPosition(fetch, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yyVAL.list = []node.Node{fetch}
		}
	case 469:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3429
		{
			fetch := expr.NewArrayDimFetch(nil, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(fetch, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[3].node))

			yyVAL.list = append(yyDollar[1].list, fetch)
		}
	case 470:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3436
		{
			fetch := expr.NewArrayDimFetch(nil, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(fetch, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[3].node))

			yyVAL.list = append(yyDollar[1].list, fetch)
		}
	case 471:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3443
		{
			fetch := expr.NewPropertyFetch(nil, yyDollar[1].node)
			yylex.(*Parser).positions.AddPosition(fetch, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))

			yyVAL.list = []node.Node{fetch}
		}
	case 472:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3453
		{
			yyVAL.node = node.NewIdentifier(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 473:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3459
		{
			yyVAL.node = yyDollar[2].node
		}
	case 474:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3464
		{
			n := expr.NewVariable(nil)
			yylex.(*Parser).positions.AddPosition(n, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(n, yyDollar[1].token.Comments())

			yyVAL.simpleIndirectReference = simpleIndirectReference{[]*expr.Variable{n}, n}
		}
	case 475:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3472
		{
			n := expr.NewVariable(nil)
			yylex.(*Parser).positions.AddPosition(n, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yylex.(*Parser).comments.AddComments(n, yyDollar[2].token.Comments())

			yyDollar[1].simpleIndirectReference.last.SetVarName(n)

			yyDollar[1].simpleIndirectReference.all = append(yyDollar[1].simpleIndirectReference.all, n)
			yyDollar[1].simpleIndirectReference.last = n
			yyVAL.simpleIndirectReference = yyDollar[1].simpleIndirectReference
		}
	case 476:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3487
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 477:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3489
		{
			if yyDollar[1].node == nil {
				yyVAL.list = []node.Node{}
			} else {
				yyVAL.list = []node.Node{yyDollar[1].node}
			}
		}
	case 478:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3501
		{
			yyVAL.node = expr.NewArrayItem(nil, yyDollar[1].node, false)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 479:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3507
		{
			item := expr.NewList(yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(item, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(item, yyDollar[1].token.Comments())

			yyVAL.node = expr.NewArrayItem(nil, item, false)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodePosition(item))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[item])
		}
	case 480:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:3517
		{
			yyVAL.node = nil
		}
	case 481:
		yyDollar = yyS[yypt-0 : yypt+1]
		//line php5/php5.y:3523
		{
			yyVAL.list = []node.Node{}
		}
	case 482:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3525
		{
			yyVAL.list = yyDollar[1].list
		}
	case 483:
		yyDollar = yyS[yypt-5 : yypt+1]
		//line php5/php5.y:3530
		{
			arrayItem := expr.NewArrayItem(yyDollar[3].node, yyDollar[5].node, false)
			yylex.(*Parser).positions.AddPosition(arrayItem, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[3].node, yyDollar[5].node))
			yylex.(*Parser).comments.AddComments(arrayItem, yylex.(*Parser).comments[yyDollar[3].node])

			yyVAL.list = append(yyDollar[1].list, arrayItem)
		}
	case 484:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3538
		{
			arrayItem := expr.NewArrayItem(nil, yyDollar[3].node, false)
			yylex.(*Parser).positions.AddPosition(arrayItem, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(arrayItem, yylex.(*Parser).comments[yyDollar[3].node])

			yyVAL.list = append(yyDollar[1].list, arrayItem)
		}
	case 485:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3546
		{
			arrayItem := expr.NewArrayItem(yyDollar[1].node, yyDollar[3].node, false)
			yylex.(*Parser).positions.AddPosition(arrayItem, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[3].node))
			yylex.(*Parser).comments.AddComments(arrayItem, yylex.(*Parser).comments[yyDollar[1].node])

			yyVAL.list = []node.Node{arrayItem}
		}
	case 486:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3554
		{
			arrayItem := expr.NewArrayItem(nil, yyDollar[1].node, false)
			yylex.(*Parser).positions.AddPosition(arrayItem, yylex.(*Parser).positionBuilder.NewNodePosition(yyDollar[1].node))
			yylex.(*Parser).comments.AddComments(arrayItem, yylex.(*Parser).comments[yyDollar[1].node])

			yyVAL.list = []node.Node{arrayItem}
		}
	case 487:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php5/php5.y:3562
		{
			arrayItem := expr.NewArrayItem(yyDollar[3].node, yyDollar[6].node, true)
			yylex.(*Parser).positions.AddPosition(arrayItem, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[3].node, yyDollar[6].node))
			yylex.(*Parser).comments.AddComments(arrayItem, yylex.(*Parser).comments[yyDollar[3].node])

			yyVAL.list = append(yyDollar[1].list, arrayItem)
		}
	case 488:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3570
		{
			arrayItem := expr.NewArrayItem(nil, yyDollar[4].node, true)
			yylex.(*Parser).positions.AddPosition(arrayItem, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[3].token, yyDollar[4].node))
			yylex.(*Parser).comments.AddComments(arrayItem, yyDollar[3].token.Comments())

			yyVAL.list = append(yyDollar[1].list, arrayItem)
		}
	case 489:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3578
		{
			arrayItem := expr.NewArrayItem(yyDollar[1].node, yyDollar[4].node, true)
			yylex.(*Parser).positions.AddPosition(arrayItem, yylex.(*Parser).positionBuilder.NewNodesPosition(yyDollar[1].node, yyDollar[4].node))
			yylex.(*Parser).comments.AddComments(arrayItem, yylex.(*Parser).comments[yyDollar[1].node])

			yyVAL.list = []node.Node{arrayItem}
		}
	case 490:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3586
		{
			arrayItem := expr.NewArrayItem(nil, yyDollar[2].node, true)
			yylex.(*Parser).positions.AddPosition(arrayItem, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(arrayItem, yyDollar[1].token.Comments())

			yyVAL.list = []node.Node{arrayItem}
		}
	case 491:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3597
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[2].node)
		}
	case 492:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3599
		{
			encapsed := scalar.NewEncapsedStringPart(yyDollar[2].token.Value)
			yylex.(*Parser).positions.AddPosition(encapsed, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.list = append(yyDollar[1].list, encapsed)
			yylex.(*Parser).comments.AddComments(encapsed, yyDollar[2].token.Comments())
		}
	case 493:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3606
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 494:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3608
		{
			encapsed := scalar.NewEncapsedStringPart(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(encapsed, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.list = []node.Node{encapsed, yyDollar[2].node}
			yylex.(*Parser).comments.AddComments(encapsed, yyDollar[1].token.Comments())
		}
	case 495:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3618
		{
			name := node.NewIdentifier(strings.TrimLeft(yyDollar[1].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(name, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node = expr.NewVariable(name)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			yylex.(*Parser).comments.AddComments(name, yyDollar[1].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 496:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3628
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[1].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node = expr.NewArrayDimFetch(variable, yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))

			yylex.(*Parser).comments.AddComments(identifier, yyDollar[1].token.Comments())
			yylex.(*Parser).comments.AddComments(variable, yyDollar[1].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 497:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3641
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[1].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			fetch := node.NewIdentifier(yyDollar[3].token.Value)
			yylex.(*Parser).positions.AddPosition(fetch, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node = expr.NewPropertyFetch(variable, fetch)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))

			yylex.(*Parser).comments.AddComments(identifier, yyDollar[1].token.Comments())
			yylex.(*Parser).comments.AddComments(variable, yyDollar[1].token.Comments())
			yylex.(*Parser).comments.AddComments(fetch, yyDollar[3].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 498:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3657
		{
			yyVAL.node = yyDollar[2].node
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[3].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 499:
		yyDollar = yyS[yypt-6 : yypt+1]
		//line php5/php5.y:3663
		{
			identifier := node.NewIdentifier(yyDollar[2].token.Value)
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			variable := expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(variable, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[2].token))
			yyVAL.node = expr.NewArrayDimFetch(variable, yyDollar[4].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[6].token))

			yylex.(*Parser).comments.AddComments(identifier, yyDollar[2].token.Comments())
			yylex.(*Parser).comments.AddComments(variable, yyDollar[1].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 500:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3677
		{
			yyVAL.node = yyDollar[2].node
		}
	case 501:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3682
		{
			yyVAL.node = scalar.NewString(yyDollar[1].token.Value)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 502:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3688
		{
			// TODO: add option to handle 64 bit integer
			if _, err := strconv.Atoi(yyDollar[1].token.Value); err == nil {
				yyVAL.node = scalar.NewLnumber(yyDollar[1].token.Value)
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			} else {
				yyVAL.node = scalar.NewString(yyDollar[1].token.Value)
				yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			}
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 503:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3700
		{
			identifier := node.NewIdentifier(strings.TrimLeft(yyDollar[1].token.Value, "$"))
			yylex.(*Parser).positions.AddPosition(identifier, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))
			yyVAL.node = expr.NewVariable(identifier)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[1].token))

			yylex.(*Parser).comments.AddComments(identifier, yyDollar[1].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 504:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3713
		{
			yyVAL.node = expr.NewIsset(yyDollar[3].list)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 505:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3719
		{
			yyVAL.node = expr.NewEmpty(yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 506:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3725
		{
			yyVAL.node = expr.NewEmpty(yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 507:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3731
		{
			yyVAL.node = expr.NewInclude(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 508:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3737
		{
			yyVAL.node = expr.NewIncludeOnce(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 509:
		yyDollar = yyS[yypt-4 : yypt+1]
		//line php5/php5.y:3743
		{
			yyVAL.node = expr.NewEval(yyDollar[3].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokensPosition(yyDollar[1].token, yyDollar[4].token))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 510:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3749
		{
			yyVAL.node = expr.NewRequire(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 511:
		yyDollar = yyS[yypt-2 : yypt+1]
		//line php5/php5.y:3755
		{
			yyVAL.node = expr.NewRequireOnce(yyDollar[2].node)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewTokenNodePosition(yyDollar[1].token, yyDollar[2].node))
			yylex.(*Parser).comments.AddComments(yyVAL.node, yyDollar[1].token.Comments())
		}
	case 512:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3764
		{
			yyVAL.list = []node.Node{yyDollar[1].node}
		}
	case 513:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3766
		{
			yyVAL.list = append(yyDollar[1].list, yyDollar[3].node)
		}
	case 514:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3771
		{
			yyVAL.node = yyDollar[1].node
		}
	case 515:
		yyDollar = yyS[yypt-1 : yypt+1]
		//line php5/php5.y:3773
		{
			yyVAL.node = yyDollar[1].node
		}
	case 516:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3778
		{
			target := node.NewIdentifier(yyDollar[3].token.Value)
			yylex.(*Parser).positions.AddPosition(target, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node = expr.NewClassConstFetch(yyDollar[1].node, target)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			yylex.(*Parser).comments.AddComments(target, yyDollar[3].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 517:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3788
		{
			target := node.NewIdentifier(yyDollar[3].token.Value)
			yylex.(*Parser).positions.AddPosition(target, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node = expr.NewClassConstFetch(yyDollar[1].node, target)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			yylex.(*Parser).comments.AddComments(target, yyDollar[3].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 518:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3801
		{
			target := node.NewIdentifier(yyDollar[3].token.Value)
			yylex.(*Parser).positions.AddPosition(target, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node = expr.NewClassConstFetch(yyDollar[1].node, target)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			yylex.(*Parser).comments.AddComments(target, yyDollar[3].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	case 519:
		yyDollar = yyS[yypt-3 : yypt+1]
		//line php5/php5.y:3814
		{
			target := node.NewIdentifier(yyDollar[3].token.Value)
			yylex.(*Parser).positions.AddPosition(target, yylex.(*Parser).positionBuilder.NewTokenPosition(yyDollar[3].token))
			yyVAL.node = expr.NewClassConstFetch(yyDollar[1].node, target)
			yylex.(*Parser).positions.AddPosition(yyVAL.node, yylex.(*Parser).positionBuilder.NewNodeTokenPosition(yyDollar[1].node, yyDollar[3].token))

			yylex.(*Parser).comments.AddComments(target, yyDollar[3].token.Comments())
			yylex.(*Parser).comments.AddComments(yyVAL.node, yylex.(*Parser).comments[yyDollar[1].node])
		}
	}
	goto yystack /* stack new state and value */
}
